from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Direct3D
import win32more.Windows.Win32.Graphics.Direct3D9
import win32more.Windows.Win32.Graphics.DirectDraw
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.System.Com
D3DRTYPECOUNT: UInt32 = 8
DIRECT3D_VERSION: UInt32 = 2304
D3D_SDK_VERSION: UInt32 = 32
D3D9b_SDK_VERSION: UInt32 = 31
D3DSPD_IUNKNOWN: Int32 = 1
D3DCREATE_FPU_PRESERVE: Int32 = 2
D3DCREATE_MULTITHREADED: Int32 = 4
D3DCREATE_PUREDEVICE: Int32 = 16
D3DCREATE_SOFTWARE_VERTEXPROCESSING: Int32 = 32
D3DCREATE_HARDWARE_VERTEXPROCESSING: Int32 = 64
D3DCREATE_MIXED_VERTEXPROCESSING: Int32 = 128
D3DCREATE_DISABLE_DRIVER_MANAGEMENT: Int32 = 256
D3DCREATE_ADAPTERGROUP_DEVICE: Int32 = 512
D3DCREATE_DISABLE_DRIVER_MANAGEMENT_EX: Int32 = 1024
D3DCREATE_NOWINDOWCHANGES: Int32 = 2048
D3DCREATE_DISABLE_PSGP_THREADING: Int32 = 8192
D3DCREATE_ENABLE_PRESENTSTATS: Int32 = 16384
D3DCREATE_DISABLE_PRINTSCREEN: Int32 = 32768
D3DCREATE_SCREENSAVER: Int32 = 268435456
D3DADAPTER_DEFAULT: UInt32 = 0
D3DENUM_WHQL_LEVEL: Int32 = 2
D3DENUM_NO_DRIVERVERSION: Int32 = 4
D3DPRESENT_BACK_BUFFERS_MAX: Int32 = 3
D3DPRESENT_BACK_BUFFERS_MAX_EX: Int32 = 30
D3DSGR_NO_CALIBRATION: Int32 = 0
D3DSGR_CALIBRATE: Int32 = 1
D3DCURSOR_IMMEDIATE_UPDATE: Int32 = 1
D3DPRESENT_DONOTWAIT: Int32 = 1
D3DPRESENT_LINEAR_CONTENT: Int32 = 2
D3DPRESENT_DONOTFLIP: Int32 = 4
D3DPRESENT_FLIPRESTART: Int32 = 8
D3DPRESENT_VIDEO_RESTRICT_TO_MONITOR: Int32 = 16
D3DPRESENT_UPDATEOVERLAYONLY: Int32 = 32
D3DPRESENT_HIDEOVERLAY: Int32 = 64
D3DPRESENT_UPDATECOLORKEY: Int32 = 128
D3DPRESENT_FORCEIMMEDIATE: Int32 = 256
_FACD3D: UInt32 = 2166
D3DVS20CAPS_PREDICATION: UInt32 = 1
D3DVS20_MAX_DYNAMICFLOWCONTROLDEPTH: UInt32 = 24
D3DVS20_MIN_DYNAMICFLOWCONTROLDEPTH: UInt32 = 0
D3DVS20_MAX_NUMTEMPS: UInt32 = 32
D3DVS20_MIN_NUMTEMPS: UInt32 = 12
D3DVS20_MAX_STATICFLOWCONTROLDEPTH: UInt32 = 4
D3DVS20_MIN_STATICFLOWCONTROLDEPTH: UInt32 = 1
D3DPS20CAPS_ARBITRARYSWIZZLE: UInt32 = 1
D3DPS20CAPS_GRADIENTINSTRUCTIONS: UInt32 = 2
D3DPS20CAPS_PREDICATION: UInt32 = 4
D3DPS20CAPS_NODEPENDENTREADLIMIT: UInt32 = 8
D3DPS20CAPS_NOTEXINSTRUCTIONLIMIT: UInt32 = 16
D3DPS20_MAX_DYNAMICFLOWCONTROLDEPTH: UInt32 = 24
D3DPS20_MIN_DYNAMICFLOWCONTROLDEPTH: UInt32 = 0
D3DPS20_MAX_NUMTEMPS: UInt32 = 32
D3DPS20_MIN_NUMTEMPS: UInt32 = 12
D3DPS20_MAX_STATICFLOWCONTROLDEPTH: UInt32 = 4
D3DPS20_MIN_STATICFLOWCONTROLDEPTH: UInt32 = 0
D3DPS20_MAX_NUMINSTRUCTIONSLOTS: UInt32 = 512
D3DPS20_MIN_NUMINSTRUCTIONSLOTS: UInt32 = 96
D3DMIN30SHADERINSTRUCTIONS: UInt32 = 512
D3DMAX30SHADERINSTRUCTIONS: UInt32 = 32768
D3DOVERLAYCAPS_FULLRANGERGB: UInt32 = 1
D3DOVERLAYCAPS_LIMITEDRANGERGB: UInt32 = 2
D3DOVERLAYCAPS_YCbCr_BT601: UInt32 = 4
D3DOVERLAYCAPS_YCbCr_BT709: UInt32 = 8
D3DOVERLAYCAPS_YCbCr_BT601_xvYCC: UInt32 = 16
D3DOVERLAYCAPS_YCbCr_BT709_xvYCC: UInt32 = 32
D3DOVERLAYCAPS_STRETCHX: UInt32 = 64
D3DOVERLAYCAPS_STRETCHY: UInt32 = 128
D3DCPCAPS_SOFTWARE: UInt32 = 1
D3DCPCAPS_HARDWARE: UInt32 = 2
D3DCPCAPS_PROTECTIONALWAYSON: UInt32 = 4
D3DCPCAPS_PARTIALDECRYPTION: UInt32 = 8
D3DCPCAPS_CONTENTKEY: UInt32 = 16
D3DCPCAPS_FRESHENSESSIONKEY: UInt32 = 32
D3DCPCAPS_ENCRYPTEDREADBACK: UInt32 = 64
D3DCPCAPS_ENCRYPTEDREADBACKKEY: UInt32 = 128
D3DCPCAPS_SEQUENTIAL_CTR_IV: UInt32 = 256
D3DCPCAPS_ENCRYPTSLICEDATAONLY: UInt32 = 512
D3DCRYPTOTYPE_AES128_CTR: Guid = Guid('{9b6bd711-4f74-41c9-9e7b-0be2d7d93b4f}')
D3DCRYPTOTYPE_PROPRIETARY: Guid = Guid('{ab4e9afd-1d1c-46e6-a72f-0869917b0de8}')
D3DKEYEXCHANGE_RSAES_OAEP: Guid = Guid('{c1949895-d72a-4a1d-8e5d-ed857d171520}')
D3DKEYEXCHANGE_DXVA: Guid = Guid('{43d3775c-38e5-4924-8d86-d3fccf153e9b}')
D3DCAPS_OVERLAY: Int32 = 2048
D3DCAPS_READ_SCANLINE: Int32 = 131072
D3DCAPS2_FULLSCREENGAMMA: Int32 = 131072
D3DCAPS2_CANCALIBRATEGAMMA: Int32 = 1048576
D3DCAPS2_RESERVED: Int32 = 33554432
D3DCAPS2_CANMANAGERESOURCE: Int32 = 268435456
D3DCAPS2_DYNAMICTEXTURES: Int32 = 536870912
D3DCAPS2_CANAUTOGENMIPMAP: Int32 = 1073741824
D3DCAPS2_CANSHARERESOURCE: Int32 = -2147483648
D3DCAPS3_RESERVED: Int32 = -2147483617
D3DCAPS3_ALPHA_FULLSCREEN_FLIP_OR_DISCARD: Int32 = 32
D3DCAPS3_LINEAR_TO_SRGB_PRESENTATION: Int32 = 128
D3DCAPS3_COPY_TO_VIDMEM: Int32 = 256
D3DCAPS3_COPY_TO_SYSTEMMEM: Int32 = 512
D3DCAPS3_DXVAHD: Int32 = 1024
D3DCAPS3_DXVAHD_LIMITED: Int32 = 2048
D3DPRESENT_INTERVAL_DEFAULT: Int32 = 0
D3DPRESENT_INTERVAL_ONE: Int32 = 1
D3DPRESENT_INTERVAL_TWO: Int32 = 2
D3DPRESENT_INTERVAL_THREE: Int32 = 4
D3DPRESENT_INTERVAL_FOUR: Int32 = 8
D3DPRESENT_INTERVAL_IMMEDIATE: Int32 = -2147483648
D3DCURSORCAPS_COLOR: Int32 = 1
D3DCURSORCAPS_LOWRES: Int32 = 2
D3DDEVCAPS_EXECUTESYSTEMMEMORY: Int32 = 16
D3DDEVCAPS_EXECUTEVIDEOMEMORY: Int32 = 32
D3DDEVCAPS_TLVERTEXSYSTEMMEMORY: Int32 = 64
D3DDEVCAPS_TLVERTEXVIDEOMEMORY: Int32 = 128
D3DDEVCAPS_TEXTURESYSTEMMEMORY: Int32 = 256
D3DDEVCAPS_TEXTUREVIDEOMEMORY: Int32 = 512
D3DDEVCAPS_DRAWPRIMTLVERTEX: Int32 = 1024
D3DDEVCAPS_CANRENDERAFTERFLIP: Int32 = 2048
D3DDEVCAPS_TEXTURENONLOCALVIDMEM: Int32 = 4096
D3DDEVCAPS_DRAWPRIMITIVES2: Int32 = 8192
D3DDEVCAPS_SEPARATETEXTUREMEMORIES: Int32 = 16384
D3DDEVCAPS_DRAWPRIMITIVES2EX: Int32 = 32768
D3DDEVCAPS_HWTRANSFORMANDLIGHT: Int32 = 65536
D3DDEVCAPS_CANBLTSYSTONONLOCAL: Int32 = 131072
D3DDEVCAPS_HWRASTERIZATION: Int32 = 524288
D3DDEVCAPS_PUREDEVICE: Int32 = 1048576
D3DDEVCAPS_QUINTICRTPATCHES: Int32 = 2097152
D3DDEVCAPS_RTPATCHES: Int32 = 4194304
D3DDEVCAPS_RTPATCHHANDLEZERO: Int32 = 8388608
D3DDEVCAPS_NPATCHES: Int32 = 16777216
D3DPMISCCAPS_MASKZ: Int32 = 2
D3DPMISCCAPS_CULLNONE: Int32 = 16
D3DPMISCCAPS_CULLCW: Int32 = 32
D3DPMISCCAPS_CULLCCW: Int32 = 64
D3DPMISCCAPS_COLORWRITEENABLE: Int32 = 128
D3DPMISCCAPS_CLIPPLANESCALEDPOINTS: Int32 = 256
D3DPMISCCAPS_CLIPTLVERTS: Int32 = 512
D3DPMISCCAPS_TSSARGTEMP: Int32 = 1024
D3DPMISCCAPS_BLENDOP: Int32 = 2048
D3DPMISCCAPS_NULLREFERENCE: Int32 = 4096
D3DPMISCCAPS_INDEPENDENTWRITEMASKS: Int32 = 16384
D3DPMISCCAPS_PERSTAGECONSTANT: Int32 = 32768
D3DPMISCCAPS_FOGANDSPECULARALPHA: Int32 = 65536
D3DPMISCCAPS_SEPARATEALPHABLEND: Int32 = 131072
D3DPMISCCAPS_MRTINDEPENDENTBITDEPTHS: Int32 = 262144
D3DPMISCCAPS_MRTPOSTPIXELSHADERBLENDING: Int32 = 524288
D3DPMISCCAPS_FOGVERTEXCLAMPED: Int32 = 1048576
D3DPMISCCAPS_POSTBLENDSRGBCONVERT: Int32 = 2097152
D3DLINECAPS_TEXTURE: Int32 = 1
D3DLINECAPS_ZTEST: Int32 = 2
D3DLINECAPS_BLEND: Int32 = 4
D3DLINECAPS_ALPHACMP: Int32 = 8
D3DLINECAPS_FOG: Int32 = 16
D3DLINECAPS_ANTIALIAS: Int32 = 32
D3DPRASTERCAPS_DITHER: Int32 = 1
D3DPRASTERCAPS_ZTEST: Int32 = 16
D3DPRASTERCAPS_FOGVERTEX: Int32 = 128
D3DPRASTERCAPS_FOGTABLE: Int32 = 256
D3DPRASTERCAPS_MIPMAPLODBIAS: Int32 = 8192
D3DPRASTERCAPS_ZBUFFERLESSHSR: Int32 = 32768
D3DPRASTERCAPS_FOGRANGE: Int32 = 65536
D3DPRASTERCAPS_ANISOTROPY: Int32 = 131072
D3DPRASTERCAPS_WBUFFER: Int32 = 262144
D3DPRASTERCAPS_WFOG: Int32 = 1048576
D3DPRASTERCAPS_ZFOG: Int32 = 2097152
D3DPRASTERCAPS_COLORPERSPECTIVE: Int32 = 4194304
D3DPRASTERCAPS_SCISSORTEST: Int32 = 16777216
D3DPRASTERCAPS_SLOPESCALEDEPTHBIAS: Int32 = 33554432
D3DPRASTERCAPS_DEPTHBIAS: Int32 = 67108864
D3DPRASTERCAPS_MULTISAMPLE_TOGGLE: Int32 = 134217728
D3DPCMPCAPS_NEVER: Int32 = 1
D3DPCMPCAPS_LESS: Int32 = 2
D3DPCMPCAPS_EQUAL: Int32 = 4
D3DPCMPCAPS_LESSEQUAL: Int32 = 8
D3DPCMPCAPS_GREATER: Int32 = 16
D3DPCMPCAPS_NOTEQUAL: Int32 = 32
D3DPCMPCAPS_GREATEREQUAL: Int32 = 64
D3DPCMPCAPS_ALWAYS: Int32 = 128
D3DPBLENDCAPS_ZERO: Int32 = 1
D3DPBLENDCAPS_ONE: Int32 = 2
D3DPBLENDCAPS_SRCCOLOR: Int32 = 4
D3DPBLENDCAPS_INVSRCCOLOR: Int32 = 8
D3DPBLENDCAPS_SRCALPHA: Int32 = 16
D3DPBLENDCAPS_INVSRCALPHA: Int32 = 32
D3DPBLENDCAPS_DESTALPHA: Int32 = 64
D3DPBLENDCAPS_INVDESTALPHA: Int32 = 128
D3DPBLENDCAPS_DESTCOLOR: Int32 = 256
D3DPBLENDCAPS_INVDESTCOLOR: Int32 = 512
D3DPBLENDCAPS_SRCALPHASAT: Int32 = 1024
D3DPBLENDCAPS_BOTHSRCALPHA: Int32 = 2048
D3DPBLENDCAPS_BOTHINVSRCALPHA: Int32 = 4096
D3DPBLENDCAPS_BLENDFACTOR: Int32 = 8192
D3DPBLENDCAPS_SRCCOLOR2: Int32 = 16384
D3DPBLENDCAPS_INVSRCCOLOR2: Int32 = 32768
D3DPSHADECAPS_COLORGOURAUDRGB: Int32 = 8
D3DPSHADECAPS_SPECULARGOURAUDRGB: Int32 = 512
D3DPSHADECAPS_ALPHAGOURAUDBLEND: Int32 = 16384
D3DPSHADECAPS_FOGGOURAUD: Int32 = 524288
D3DPTEXTURECAPS_PERSPECTIVE: Int32 = 1
D3DPTEXTURECAPS_POW2: Int32 = 2
D3DPTEXTURECAPS_ALPHA: Int32 = 4
D3DPTEXTURECAPS_SQUAREONLY: Int32 = 32
D3DPTEXTURECAPS_TEXREPEATNOTSCALEDBYSIZE: Int32 = 64
D3DPTEXTURECAPS_ALPHAPALETTE: Int32 = 128
D3DPTEXTURECAPS_NONPOW2CONDITIONAL: Int32 = 256
D3DPTEXTURECAPS_PROJECTED: Int32 = 1024
D3DPTEXTURECAPS_CUBEMAP: Int32 = 2048
D3DPTEXTURECAPS_VOLUMEMAP: Int32 = 8192
D3DPTEXTURECAPS_MIPMAP: Int32 = 16384
D3DPTEXTURECAPS_MIPVOLUMEMAP: Int32 = 32768
D3DPTEXTURECAPS_MIPCUBEMAP: Int32 = 65536
D3DPTEXTURECAPS_CUBEMAP_POW2: Int32 = 131072
D3DPTEXTURECAPS_VOLUMEMAP_POW2: Int32 = 262144
D3DPTEXTURECAPS_NOPROJECTEDBUMPENV: Int32 = 2097152
D3DPTFILTERCAPS_MINFPOINT: Int32 = 256
D3DPTFILTERCAPS_MINFLINEAR: Int32 = 512
D3DPTFILTERCAPS_MINFANISOTROPIC: Int32 = 1024
D3DPTFILTERCAPS_MINFPYRAMIDALQUAD: Int32 = 2048
D3DPTFILTERCAPS_MINFGAUSSIANQUAD: Int32 = 4096
D3DPTFILTERCAPS_MIPFPOINT: Int32 = 65536
D3DPTFILTERCAPS_MIPFLINEAR: Int32 = 131072
D3DPTFILTERCAPS_CONVOLUTIONMONO: Int32 = 262144
D3DPTFILTERCAPS_MAGFPOINT: Int32 = 16777216
D3DPTFILTERCAPS_MAGFLINEAR: Int32 = 33554432
D3DPTFILTERCAPS_MAGFANISOTROPIC: Int32 = 67108864
D3DPTFILTERCAPS_MAGFPYRAMIDALQUAD: Int32 = 134217728
D3DPTFILTERCAPS_MAGFGAUSSIANQUAD: Int32 = 268435456
D3DPTADDRESSCAPS_WRAP: Int32 = 1
D3DPTADDRESSCAPS_MIRROR: Int32 = 2
D3DPTADDRESSCAPS_CLAMP: Int32 = 4
D3DPTADDRESSCAPS_BORDER: Int32 = 8
D3DPTADDRESSCAPS_INDEPENDENTUV: Int32 = 16
D3DPTADDRESSCAPS_MIRRORONCE: Int32 = 32
D3DSTENCILCAPS_KEEP: Int32 = 1
D3DSTENCILCAPS_ZERO: Int32 = 2
D3DSTENCILCAPS_REPLACE: Int32 = 4
D3DSTENCILCAPS_INCRSAT: Int32 = 8
D3DSTENCILCAPS_DECRSAT: Int32 = 16
D3DSTENCILCAPS_INVERT: Int32 = 32
D3DSTENCILCAPS_INCR: Int32 = 64
D3DSTENCILCAPS_DECR: Int32 = 128
D3DSTENCILCAPS_TWOSIDED: Int32 = 256
D3DTEXOPCAPS_DISABLE: Int32 = 1
D3DTEXOPCAPS_SELECTARG1: Int32 = 2
D3DTEXOPCAPS_SELECTARG2: Int32 = 4
D3DTEXOPCAPS_MODULATE: Int32 = 8
D3DTEXOPCAPS_MODULATE2X: Int32 = 16
D3DTEXOPCAPS_MODULATE4X: Int32 = 32
D3DTEXOPCAPS_ADD: Int32 = 64
D3DTEXOPCAPS_ADDSIGNED: Int32 = 128
D3DTEXOPCAPS_ADDSIGNED2X: Int32 = 256
D3DTEXOPCAPS_SUBTRACT: Int32 = 512
D3DTEXOPCAPS_ADDSMOOTH: Int32 = 1024
D3DTEXOPCAPS_BLENDDIFFUSEALPHA: Int32 = 2048
D3DTEXOPCAPS_BLENDTEXTUREALPHA: Int32 = 4096
D3DTEXOPCAPS_BLENDFACTORALPHA: Int32 = 8192
D3DTEXOPCAPS_BLENDTEXTUREALPHAPM: Int32 = 16384
D3DTEXOPCAPS_BLENDCURRENTALPHA: Int32 = 32768
D3DTEXOPCAPS_PREMODULATE: Int32 = 65536
D3DTEXOPCAPS_MODULATEALPHA_ADDCOLOR: Int32 = 131072
D3DTEXOPCAPS_MODULATECOLOR_ADDALPHA: Int32 = 262144
D3DTEXOPCAPS_MODULATEINVALPHA_ADDCOLOR: Int32 = 524288
D3DTEXOPCAPS_MODULATEINVCOLOR_ADDALPHA: Int32 = 1048576
D3DTEXOPCAPS_BUMPENVMAP: Int32 = 2097152
D3DTEXOPCAPS_BUMPENVMAPLUMINANCE: Int32 = 4194304
D3DTEXOPCAPS_DOTPRODUCT3: Int32 = 8388608
D3DTEXOPCAPS_MULTIPLYADD: Int32 = 16777216
D3DTEXOPCAPS_LERP: Int32 = 33554432
D3DFVFCAPS_TEXCOORDCOUNTMASK: Int32 = 65535
D3DFVFCAPS_DONOTSTRIPELEMENTS: Int32 = 524288
D3DFVFCAPS_PSIZE: Int32 = 1048576
D3DVTXPCAPS_TEXGEN: Int32 = 1
D3DVTXPCAPS_MATERIALSOURCE7: Int32 = 2
D3DVTXPCAPS_DIRECTIONALLIGHTS: Int32 = 8
D3DVTXPCAPS_POSITIONALLIGHTS: Int32 = 16
D3DVTXPCAPS_LOCALVIEWER: Int32 = 32
D3DVTXPCAPS_TWEENING: Int32 = 64
D3DVTXPCAPS_TEXGEN_SPHEREMAP: Int32 = 256
D3DVTXPCAPS_NO_TEXGEN_NONLOCALVIEWER: Int32 = 512
D3DDEVCAPS2_STREAMOFFSET: Int32 = 1
D3DDEVCAPS2_DMAPNPATCH: Int32 = 2
D3DDEVCAPS2_ADAPTIVETESSRTPATCH: Int32 = 4
D3DDEVCAPS2_ADAPTIVETESSNPATCH: Int32 = 8
D3DDEVCAPS2_CAN_STRETCHRECT_FROM_TEXTURES: Int32 = 16
D3DDEVCAPS2_PRESAMPLEDDMAPNPATCH: Int32 = 32
D3DDEVCAPS2_VERTEXELEMENTSCANSHARESTREAMOFFSET: Int32 = 64
D3DDTCAPS_UBYTE4: Int32 = 1
D3DDTCAPS_UBYTE4N: Int32 = 2
D3DDTCAPS_SHORT2N: Int32 = 4
D3DDTCAPS_SHORT4N: Int32 = 8
D3DDTCAPS_USHORT2N: Int32 = 16
D3DDTCAPS_USHORT4N: Int32 = 32
D3DDTCAPS_UDEC3: Int32 = 64
D3DDTCAPS_DEC3N: Int32 = 128
D3DDTCAPS_FLOAT16_2: Int32 = 256
D3DDTCAPS_FLOAT16_4: Int32 = 512
D3DMAXUSERCLIPPLANES: UInt32 = 32
D3DCLIPPLANE0: UInt32 = 1
D3DCLIPPLANE1: UInt32 = 2
D3DCLIPPLANE2: UInt32 = 4
D3DCLIPPLANE3: UInt32 = 8
D3DCLIPPLANE4: UInt32 = 16
D3DCLIPPLANE5: UInt32 = 32
D3DCS_LEFT: Int32 = 1
D3DCS_RIGHT: Int32 = 2
D3DCS_TOP: Int32 = 4
D3DCS_BOTTOM: Int32 = 8
D3DCS_FRONT: Int32 = 16
D3DCS_BACK: Int32 = 32
D3DCS_PLANE0: Int32 = 64
D3DCS_PLANE1: Int32 = 128
D3DCS_PLANE2: Int32 = 256
D3DCS_PLANE3: Int32 = 512
D3DCS_PLANE4: Int32 = 1024
D3DCS_PLANE5: Int32 = 2048
D3DCLEAR_TARGET: Int32 = 1
D3DCLEAR_ZBUFFER: Int32 = 2
D3DCLEAR_STENCIL: Int32 = 4
D3D_MAX_SIMULTANEOUS_RENDERTARGETS: UInt32 = 4
D3DRENDERSTATE_WRAPBIAS: UInt32 = 128
D3DWRAP_U: Int32 = 1
D3DWRAP_V: Int32 = 2
D3DWRAP_W: Int32 = 4
D3DWRAPCOORD_0: Int32 = 1
D3DWRAPCOORD_1: Int32 = 2
D3DWRAPCOORD_2: Int32 = 4
D3DWRAPCOORD_3: Int32 = 8
D3DDMAPSAMPLER: UInt32 = 256
D3DVERTEXTEXTURESAMPLER0: UInt32 = 257
D3DVERTEXTEXTURESAMPLER1: UInt32 = 258
D3DVERTEXTEXTURESAMPLER2: UInt32 = 259
D3DVERTEXTEXTURESAMPLER3: UInt32 = 260
D3DTSS_TCI_PASSTHRU: UInt32 = 0
D3DTSS_TCI_CAMERASPACENORMAL: UInt32 = 65536
D3DTSS_TCI_CAMERASPACEPOSITION: UInt32 = 131072
D3DTSS_TCI_CAMERASPACEREFLECTIONVECTOR: UInt32 = 196608
D3DTSS_TCI_SPHEREMAP: UInt32 = 262144
D3DTA_SELECTMASK: UInt32 = 15
D3DTA_DIFFUSE: UInt32 = 0
D3DTA_CURRENT: UInt32 = 1
D3DTA_TEXTURE: UInt32 = 2
D3DTA_TFACTOR: UInt32 = 3
D3DTA_SPECULAR: UInt32 = 4
D3DTA_TEMP: UInt32 = 5
D3DTA_CONSTANT: UInt32 = 6
D3DTA_COMPLEMENT: UInt32 = 16
D3DTA_ALPHAREPLICATE: UInt32 = 32
D3DPV_DONOTCOPYDATA: UInt32 = 1
D3DFVF_RESERVED0: UInt32 = 1
D3DFVF_POSITION_MASK: UInt32 = 16398
D3DFVF_XYZ: UInt32 = 2
D3DFVF_XYZRHW: UInt32 = 4
D3DFVF_XYZB1: UInt32 = 6
D3DFVF_XYZB2: UInt32 = 8
D3DFVF_XYZB3: UInt32 = 10
D3DFVF_XYZB4: UInt32 = 12
D3DFVF_XYZB5: UInt32 = 14
D3DFVF_XYZW: UInt32 = 16386
D3DFVF_NORMAL: UInt32 = 16
D3DFVF_PSIZE: UInt32 = 32
D3DFVF_DIFFUSE: UInt32 = 64
D3DFVF_SPECULAR: UInt32 = 128
D3DFVF_TEXCOUNT_MASK: UInt32 = 3840
D3DFVF_TEXCOUNT_SHIFT: UInt32 = 8
D3DFVF_TEX0: UInt32 = 0
D3DFVF_TEX1: UInt32 = 256
D3DFVF_TEX2: UInt32 = 512
D3DFVF_TEX3: UInt32 = 768
D3DFVF_TEX4: UInt32 = 1024
D3DFVF_TEX5: UInt32 = 1280
D3DFVF_TEX6: UInt32 = 1536
D3DFVF_TEX7: UInt32 = 1792
D3DFVF_TEX8: UInt32 = 2048
D3DFVF_LASTBETA_UBYTE4: UInt32 = 4096
D3DFVF_LASTBETA_D3DCOLOR: UInt32 = 32768
D3DFVF_RESERVED2: UInt32 = 24576
MAXD3DDECLUSAGEINDEX: UInt32 = 15
MAXD3DDECLLENGTH: UInt32 = 64
D3DDP_MAXTEXCOORD: UInt32 = 8
D3DSTREAMSOURCE_INDEXEDDATA: UInt32 = 1073741824
D3DSTREAMSOURCE_INSTANCEDATA: UInt32 = 2147483648
D3DSI_OPCODE_MASK: UInt32 = 65535
D3DSI_INSTLENGTH_MASK: UInt32 = 251658240
D3DSI_INSTLENGTH_SHIFT: UInt32 = 24
D3DSI_COISSUE: UInt32 = 1073741824
D3DSP_OPCODESPECIFICCONTROL_MASK: UInt32 = 16711680
D3DSP_OPCODESPECIFICCONTROL_SHIFT: UInt32 = 16
D3DSHADER_COMPARISON_SHIFT: UInt32 = 16
D3DSP_DCL_USAGE_SHIFT: UInt32 = 0
D3DSP_DCL_USAGE_MASK: UInt32 = 15
D3DSP_DCL_USAGEINDEX_SHIFT: UInt32 = 16
D3DSP_DCL_USAGEINDEX_MASK: UInt32 = 983040
D3DSP_TEXTURETYPE_SHIFT: UInt32 = 27
D3DSP_TEXTURETYPE_MASK: UInt32 = 2013265920
D3DSP_REGNUM_MASK: UInt32 = 2047
D3DSP_WRITEMASK_0: UInt32 = 65536
D3DSP_WRITEMASK_1: UInt32 = 131072
D3DSP_WRITEMASK_2: UInt32 = 262144
D3DSP_WRITEMASK_3: UInt32 = 524288
D3DSP_WRITEMASK_ALL: UInt32 = 983040
D3DSP_DSTMOD_SHIFT: UInt32 = 20
D3DSP_DSTMOD_MASK: UInt32 = 15728640
D3DSP_DSTSHIFT_SHIFT: UInt32 = 24
D3DSP_DSTSHIFT_MASK: UInt32 = 251658240
D3DSP_REGTYPE_SHIFT: UInt32 = 28
D3DSP_REGTYPE_SHIFT2: UInt32 = 8
D3DSP_REGTYPE_MASK: UInt32 = 1879048192
D3DSP_REGTYPE_MASK2: UInt32 = 6144
D3DVS_ADDRESSMODE_SHIFT: UInt32 = 13
D3DSHADER_ADDRESSMODE_SHIFT: UInt32 = 13
D3DVS_SWIZZLE_SHIFT: UInt32 = 16
D3DVS_SWIZZLE_MASK: UInt32 = 16711680
D3DSP_SWIZZLE_SHIFT: UInt32 = 16
D3DSP_SWIZZLE_MASK: UInt32 = 16711680
D3DSP_SRCMOD_SHIFT: UInt32 = 24
D3DSP_SRCMOD_MASK: UInt32 = 251658240
D3DSP_MIN_PRECISION_SHIFT: UInt32 = 14
D3DSP_MIN_PRECISION_MASK: UInt32 = 49152
D3DSI_COMMENTSIZE_SHIFT: UInt32 = 16
D3DSI_COMMENTSIZE_MASK: UInt32 = 2147418112
D3DFVF_TEXTUREFORMAT2: UInt32 = 0
D3DFVF_TEXTUREFORMAT1: UInt32 = 3
D3DFVF_TEXTUREFORMAT3: UInt32 = 1
D3DFVF_TEXTUREFORMAT4: UInt32 = 2
D3DPRESENT_RATE_DEFAULT: UInt32 = 0
D3DPRESENTFLAG_LOCKABLE_BACKBUFFER: UInt32 = 1
D3DPRESENTFLAG_DISCARD_DEPTHSTENCIL: UInt32 = 2
D3DPRESENTFLAG_DEVICECLIP: UInt32 = 4
D3DPRESENTFLAG_VIDEO: UInt32 = 16
D3DPRESENTFLAG_NOAUTOROTATE: UInt32 = 32
D3DPRESENTFLAG_UNPRUNEDMODE: UInt32 = 64
D3DPRESENTFLAG_OVERLAY_LIMITEDRGB: UInt32 = 128
D3DPRESENTFLAG_OVERLAY_YCbCr_BT709: UInt32 = 256
D3DPRESENTFLAG_OVERLAY_YCbCr_xvYCC: UInt32 = 512
D3DPRESENTFLAG_RESTRICTED_CONTENT: UInt32 = 1024
D3DPRESENTFLAG_RESTRICT_SHARED_RESOURCE_DRIVER: UInt32 = 2048
D3DUSAGE_RENDERTARGET: Int32 = 1
D3DUSAGE_DEPTHSTENCIL: Int32 = 2
D3DUSAGE_DYNAMIC: Int32 = 512
D3DUSAGE_NONSECURE: Int32 = 8388608
D3DUSAGE_AUTOGENMIPMAP: Int32 = 1024
D3DUSAGE_DMAP: Int32 = 16384
D3DUSAGE_QUERY_LEGACYBUMPMAP: Int32 = 32768
D3DUSAGE_QUERY_SRGBREAD: Int32 = 65536
D3DUSAGE_QUERY_FILTER: Int32 = 131072
D3DUSAGE_QUERY_SRGBWRITE: Int32 = 262144
D3DUSAGE_QUERY_POSTPIXELSHADER_BLENDING: Int32 = 524288
D3DUSAGE_QUERY_VERTEXTEXTURE: Int32 = 1048576
D3DUSAGE_QUERY_WRAPANDMIP: Int32 = 2097152
D3DUSAGE_WRITEONLY: Int32 = 8
D3DUSAGE_SOFTWAREPROCESSING: Int32 = 16
D3DUSAGE_DONOTCLIP: Int32 = 32
D3DUSAGE_POINTS: Int32 = 64
D3DUSAGE_RTPATCHES: Int32 = 128
D3DUSAGE_NPATCHES: Int32 = 256
D3DUSAGE_TEXTAPI: Int32 = 268435456
D3DUSAGE_RESTRICTED_CONTENT: Int32 = 2048
D3DUSAGE_RESTRICT_SHARED_RESOURCE: Int32 = 8192
D3DUSAGE_RESTRICT_SHARED_RESOURCE_DRIVER: Int32 = 4096
D3DLOCK_READONLY: Int32 = 16
D3DLOCK_DISCARD: Int32 = 8192
D3DLOCK_NOOVERWRITE: Int32 = 4096
D3DLOCK_NOSYSLOCK: Int32 = 2048
D3DLOCK_DONOTWAIT: Int32 = 16384
D3DLOCK_NO_DIRTY_UPDATE: Int32 = 32768
MAX_DEVICE_IDENTIFIER_STRING: UInt32 = 512
D3DISSUE_END: UInt32 = 1
D3DISSUE_BEGIN: UInt32 = 2
D3DGETDATA_FLUSH: UInt32 = 1
D3DCOMPOSERECTS_MAXNUMRECTS: UInt32 = 65535
D3DCONVOLUTIONMONO_MAXWIDTH: UInt32 = 7
D3DCONVOLUTIONMONO_MAXHEIGHT: UInt32 = 7
D3DFMT_A1_SURFACE_MAXWIDTH: UInt32 = 8192
D3DFMT_A1_SURFACE_MAXHEIGHT: UInt32 = 2048
D3D9_RESOURCE_PRIORITY_MINIMUM: UInt32 = 671088640
D3D9_RESOURCE_PRIORITY_LOW: UInt32 = 1342177280
D3D9_RESOURCE_PRIORITY_NORMAL: UInt32 = 2013265920
D3D9_RESOURCE_PRIORITY_HIGH: UInt32 = 2684354560
D3D9_RESOURCE_PRIORITY_MAXIMUM: UInt32 = 3355443200
D3D_OMAC_SIZE: UInt32 = 16
D3DAUTHENTICATEDQUERY_PROTECTION: Guid = Guid('{a84eb584-c495-48aa-b94d-8bd2d6fbce05}')
D3DAUTHENTICATEDQUERY_CHANNELTYPE: Guid = Guid('{bc1b18a5-b1fb-42ab-bd94-b5828b4bf7be}')
D3DAUTHENTICATEDQUERY_DEVICEHANDLE: Guid = Guid('{ec1c539d-8cff-4e2a-bcc4-f5692f99f480}')
D3DAUTHENTICATEDQUERY_CRYPTOSESSION: Guid = Guid('{2634499e-d018-4d74-ac17-7f724059528d}')
D3DAUTHENTICATEDQUERY_RESTRICTEDSHAREDRESOURCEPROCESSCOUNT: Guid = Guid('{0db207b3-9450-46a6-82de-1b96d44f9cf2}')
D3DAUTHENTICATEDQUERY_RESTRICTEDSHAREDRESOURCEPROCESS: Guid = Guid('{649bbadb-f0f4-4639-a15b-24393fc3abac}')
D3DAUTHENTICATEDQUERY_UNRESTRICTEDPROTECTEDSHAREDRESOURCECOUNT: Guid = Guid('{012f0bd6-e662-4474-befd-aa53e5143c6d}')
D3DAUTHENTICATEDQUERY_OUTPUTIDCOUNT: Guid = Guid('{2c042b5e-8c07-46d5-aabe-8f75cbad4c31}')
D3DAUTHENTICATEDQUERY_OUTPUTID: Guid = Guid('{839ddca3-9b4e-41e4-b053-892bd2a11ee7}')
D3DAUTHENTICATEDQUERY_ACCESSIBILITYATTRIBUTES: Guid = Guid('{6214d9d2-432c-4abb-9fce-216eea269e3b}')
D3DAUTHENTICATEDQUERY_ENCRYPTIONWHENACCESSIBLEGUIDCOUNT: Guid = Guid('{b30f7066-203c-4b07-93fc-ceaafd61241e}')
D3DAUTHENTICATEDQUERY_ENCRYPTIONWHENACCESSIBLEGUID: Guid = Guid('{f83a5958-e986-4bda-beb0-411f6a7a01b7}')
D3DAUTHENTICATEDQUERY_CURRENTENCRYPTIONWHENACCESSIBLE: Guid = Guid('{ec1791c7-dad3-4f15-9ec3-faa93d60d4f0}')
D3DAUTHENTICATEDCONFIGURE_INITIALIZE: Guid = Guid('{06114bdb-3523-470a-8dca-fbc2845154f0}')
D3DAUTHENTICATEDCONFIGURE_PROTECTION: Guid = Guid('{50455658-3f47-4362-bf99-bfdfcde9ed29}')
D3DAUTHENTICATEDCONFIGURE_CRYPTOSESSION: Guid = Guid('{6346cc54-2cfc-4ad4-8224-d15837de7700}')
D3DAUTHENTICATEDCONFIGURE_SHAREDRESOURCE: Guid = Guid('{0772d047-1b40-48e8-9ca6-b5f510de9f01}')
D3DAUTHENTICATEDCONFIGURE_ENCRYPTIONWHENACCESSIBLE: Guid = Guid('{41fff286-6ae0-4d43-9d55-a46e9efd158a}')
D3DTRANSFORMCAPS_CLIP: Int32 = 1
D3DLIGHTINGMODEL_RGB: Int32 = 1
D3DLIGHTINGMODEL_MONO: Int32 = 2
D3DLIGHTCAPS_POINT: Int32 = 1
D3DLIGHTCAPS_SPOT: Int32 = 2
D3DLIGHTCAPS_DIRECTIONAL: Int32 = 4
D3DLIGHTCAPS_PARALLELPOINT: Int32 = 8
D3DLIGHTCAPS_GLSPOT: Int32 = 16
D3DPMISCCAPS_MASKPLANES: Int32 = 1
D3DPMISCCAPS_LINEPATTERNREP: Int32 = 4
D3DPMISCCAPS_CONFORMANT: Int32 = 8
D3DPRASTERCAPS_ROP2: Int32 = 2
D3DPRASTERCAPS_XOR: Int32 = 4
D3DPRASTERCAPS_PAT: Int32 = 8
D3DPRASTERCAPS_SUBPIXEL: Int32 = 32
D3DPRASTERCAPS_SUBPIXELX: Int32 = 64
D3DPRASTERCAPS_STIPPLE: Int32 = 512
D3DPRASTERCAPS_ANTIALIASSORTDEPENDENT: Int32 = 1024
D3DPRASTERCAPS_ANTIALIASSORTINDEPENDENT: Int32 = 2048
D3DPRASTERCAPS_ANTIALIASEDGES: Int32 = 4096
D3DPRASTERCAPS_ZBIAS: Int32 = 16384
D3DPRASTERCAPS_TRANSLUCENTSORTINDEPENDENT: Int32 = 524288
D3DPSHADECAPS_COLORFLATMONO: Int32 = 1
D3DPSHADECAPS_COLORFLATRGB: Int32 = 2
D3DPSHADECAPS_COLORGOURAUDMONO: Int32 = 4
D3DPSHADECAPS_COLORPHONGMONO: Int32 = 16
D3DPSHADECAPS_COLORPHONGRGB: Int32 = 32
D3DPSHADECAPS_SPECULARFLATMONO: Int32 = 64
D3DPSHADECAPS_SPECULARFLATRGB: Int32 = 128
D3DPSHADECAPS_SPECULARGOURAUDMONO: Int32 = 256
D3DPSHADECAPS_SPECULARPHONGMONO: Int32 = 1024
D3DPSHADECAPS_SPECULARPHONGRGB: Int32 = 2048
D3DPSHADECAPS_ALPHAFLATBLEND: Int32 = 4096
D3DPSHADECAPS_ALPHAFLATSTIPPLED: Int32 = 8192
D3DPSHADECAPS_ALPHAGOURAUDSTIPPLED: Int32 = 32768
D3DPSHADECAPS_ALPHAPHONGBLEND: Int32 = 65536
D3DPSHADECAPS_ALPHAPHONGSTIPPLED: Int32 = 131072
D3DPSHADECAPS_FOGFLAT: Int32 = 262144
D3DPSHADECAPS_FOGPHONG: Int32 = 1048576
D3DPTEXTURECAPS_TRANSPARENCY: Int32 = 8
D3DPTEXTURECAPS_BORDER: Int32 = 16
D3DPTEXTURECAPS_COLORKEYBLEND: Int32 = 4096
D3DPTFILTERCAPS_NEAREST: Int32 = 1
D3DPTFILTERCAPS_LINEAR: Int32 = 2
D3DPTFILTERCAPS_MIPNEAREST: Int32 = 4
D3DPTFILTERCAPS_MIPLINEAR: Int32 = 8
D3DPTFILTERCAPS_LINEARMIPNEAREST: Int32 = 16
D3DPTFILTERCAPS_LINEARMIPLINEAR: Int32 = 32
D3DPTFILTERCAPS_MAGFAFLATCUBIC: Int32 = 134217728
D3DPTFILTERCAPS_MAGFGAUSSIANCUBIC: Int32 = 268435456
D3DPTBLENDCAPS_DECAL: Int32 = 1
D3DPTBLENDCAPS_MODULATE: Int32 = 2
D3DPTBLENDCAPS_DECALALPHA: Int32 = 4
D3DPTBLENDCAPS_MODULATEALPHA: Int32 = 8
D3DPTBLENDCAPS_DECALMASK: Int32 = 16
D3DPTBLENDCAPS_MODULATEMASK: Int32 = 32
D3DPTBLENDCAPS_COPY: Int32 = 64
D3DPTBLENDCAPS_ADD: Int32 = 128
D3DDD_COLORMODEL: Int32 = 1
D3DDD_DEVCAPS: Int32 = 2
D3DDD_TRANSFORMCAPS: Int32 = 4
D3DDD_LIGHTINGCAPS: Int32 = 8
D3DDD_BCLIPPING: Int32 = 16
D3DDD_LINECAPS: Int32 = 32
D3DDD_TRICAPS: Int32 = 64
D3DDD_DEVICERENDERBITDEPTH: Int32 = 128
D3DDD_DEVICEZBUFFERBITDEPTH: Int32 = 256
D3DDD_MAXBUFFERSIZE: Int32 = 512
D3DDD_MAXVERTEXCOUNT: Int32 = 1024
D3DDEVCAPS_FLOATTLVERTEX: Int32 = 1
D3DDEVCAPS_SORTINCREASINGZ: Int32 = 2
D3DDEVCAPS_SORTDECREASINGZ: Int32 = 4
D3DDEVCAPS_SORTEXACT: Int32 = 8
D3DVTXPCAPS_VERTEXFOG: Int32 = 4
D3DFDS_COLORMODEL: Int32 = 1
D3DFDS_GUID: Int32 = 2
D3DFDS_HARDWARE: Int32 = 4
D3DFDS_TRIANGLES: Int32 = 8
D3DFDS_LINES: Int32 = 16
D3DFDS_MISCCAPS: Int32 = 32
D3DFDS_RASTERCAPS: Int32 = 64
D3DFDS_ZCMPCAPS: Int32 = 128
D3DFDS_ALPHACMPCAPS: Int32 = 256
D3DFDS_SRCBLENDCAPS: Int32 = 512
D3DFDS_DSTBLENDCAPS: Int32 = 1024
D3DFDS_SHADECAPS: Int32 = 2048
D3DFDS_TEXTURECAPS: Int32 = 4096
D3DFDS_TEXTUREFILTERCAPS: Int32 = 8192
D3DFDS_TEXTUREBLENDCAPS: Int32 = 16384
D3DFDS_TEXTUREADDRESSCAPS: Int32 = 32768
D3DDEB_BUFSIZE: Int32 = 1
D3DDEB_CAPS: Int32 = 2
D3DDEB_LPDATA: Int32 = 4
D3DDEBCAPS_SYSTEMMEMORY: Int32 = 1
D3DDEBCAPS_VIDEOMEMORY: Int32 = 2
D3DCLIP_LEFT: Int32 = 1
D3DCLIP_RIGHT: Int32 = 2
D3DCLIP_TOP: Int32 = 4
D3DCLIP_BOTTOM: Int32 = 8
D3DCLIP_FRONT: Int32 = 16
D3DCLIP_BACK: Int32 = 32
D3DCLIP_GEN0: Int32 = 64
D3DCLIP_GEN1: Int32 = 128
D3DCLIP_GEN2: Int32 = 256
D3DCLIP_GEN3: Int32 = 512
D3DCLIP_GEN4: Int32 = 1024
D3DCLIP_GEN5: Int32 = 2048
D3DSTATUS_CLIPUNIONLEFT: Int32 = 1
D3DSTATUS_CLIPUNIONRIGHT: Int32 = 2
D3DSTATUS_CLIPUNIONTOP: Int32 = 4
D3DSTATUS_CLIPUNIONBOTTOM: Int32 = 8
D3DSTATUS_CLIPUNIONFRONT: Int32 = 16
D3DSTATUS_CLIPUNIONBACK: Int32 = 32
D3DSTATUS_CLIPUNIONGEN0: Int32 = 64
D3DSTATUS_CLIPUNIONGEN1: Int32 = 128
D3DSTATUS_CLIPUNIONGEN2: Int32 = 256
D3DSTATUS_CLIPUNIONGEN3: Int32 = 512
D3DSTATUS_CLIPUNIONGEN4: Int32 = 1024
D3DSTATUS_CLIPUNIONGEN5: Int32 = 2048
D3DSTATUS_CLIPINTERSECTIONLEFT: Int32 = 4096
D3DSTATUS_CLIPINTERSECTIONRIGHT: Int32 = 8192
D3DSTATUS_CLIPINTERSECTIONTOP: Int32 = 16384
D3DSTATUS_CLIPINTERSECTIONBOTTOM: Int32 = 32768
D3DSTATUS_CLIPINTERSECTIONFRONT: Int32 = 65536
D3DSTATUS_CLIPINTERSECTIONBACK: Int32 = 131072
D3DSTATUS_CLIPINTERSECTIONGEN0: Int32 = 262144
D3DSTATUS_CLIPINTERSECTIONGEN1: Int32 = 524288
D3DSTATUS_CLIPINTERSECTIONGEN2: Int32 = 1048576
D3DSTATUS_CLIPINTERSECTIONGEN3: Int32 = 2097152
D3DSTATUS_CLIPINTERSECTIONGEN4: Int32 = 4194304
D3DSTATUS_CLIPINTERSECTIONGEN5: Int32 = 8388608
D3DSTATUS_ZNOTVISIBLE: Int32 = 16777216
D3DTRANSFORM_CLIPPED: Int32 = 1
D3DTRANSFORM_UNCLIPPED: Int32 = 2
D3DLIGHT_ACTIVE: UInt32 = 1
D3DLIGHT_NO_SPECULAR: UInt32 = 2
D3DCOLOR_MONO: UInt32 = 1
D3DCOLOR_RGB: UInt32 = 2
D3DSTATE_OVERRIDE_BIAS: UInt32 = 256
D3DPROCESSVERTICES_TRANSFORMLIGHT: Int32 = 0
D3DPROCESSVERTICES_TRANSFORM: Int32 = 1
D3DPROCESSVERTICES_COPY: Int32 = 2
D3DPROCESSVERTICES_OPMASK: Int32 = 7
D3DPROCESSVERTICES_UPDATEEXTENTS: Int32 = 8
D3DPROCESSVERTICES_NOCOLOR: Int32 = 16
D3DTRIFLAG_START: Int32 = 0
D3DTRIFLAG_ODD: Int32 = 30
D3DTRIFLAG_EVEN: Int32 = 31
D3DTRIFLAG_EDGEENABLE1: Int32 = 256
D3DTRIFLAG_EDGEENABLE2: Int32 = 512
D3DTRIFLAG_EDGEENABLE3: Int32 = 1024
D3DSETSTATUS_STATUS: Int32 = 1
D3DSETSTATUS_EXTENTS: Int32 = 2
D3DCLIPSTATUS_STATUS: Int32 = 1
D3DCLIPSTATUS_EXTENTS2: Int32 = 2
D3DCLIPSTATUS_EXTENTS3: Int32 = 4
D3DEXECUTE_CLIPPED: Int32 = 1
D3DEXECUTE_UNCLIPPED: Int32 = 2
D3DPAL_FREE: UInt32 = 0
D3DPAL_READONLY: UInt32 = 64
D3DPAL_RESERVED: UInt32 = 128
D3DVBCAPS_SYSTEMMEMORY: Int32 = 2048
D3DVBCAPS_WRITEONLY: Int32 = 65536
D3DVBCAPS_OPTIMIZED: Int32 = -2147483648
D3DVBCAPS_DONOTCLIP: Int32 = 1
D3DVOP_LIGHT: UInt32 = 1024
D3DVOP_TRANSFORM: UInt32 = 1
D3DVOP_CLIP: UInt32 = 4
D3DVOP_EXTENTS: UInt32 = 8
D3DFVF_RESERVED1: UInt32 = 32
D3DVIS_INSIDE_FRUSTUM: UInt32 = 0
D3DVIS_INTERSECT_FRUSTUM: UInt32 = 1
D3DVIS_OUTSIDE_FRUSTUM: UInt32 = 2
D3DVIS_INSIDE_LEFT: UInt32 = 0
D3DVIS_INTERSECT_LEFT: UInt32 = 4
D3DVIS_OUTSIDE_LEFT: UInt32 = 8
D3DVIS_INSIDE_RIGHT: UInt32 = 0
D3DVIS_INTERSECT_RIGHT: UInt32 = 16
D3DVIS_OUTSIDE_RIGHT: UInt32 = 32
D3DVIS_INSIDE_TOP: UInt32 = 0
D3DVIS_INTERSECT_TOP: UInt32 = 64
D3DVIS_OUTSIDE_TOP: UInt32 = 128
D3DVIS_INSIDE_BOTTOM: UInt32 = 0
D3DVIS_INTERSECT_BOTTOM: UInt32 = 256
D3DVIS_OUTSIDE_BOTTOM: UInt32 = 512
D3DVIS_INSIDE_NEAR: UInt32 = 0
D3DVIS_INTERSECT_NEAR: UInt32 = 1024
D3DVIS_OUTSIDE_NEAR: UInt32 = 2048
D3DVIS_INSIDE_FAR: UInt32 = 0
D3DVIS_INTERSECT_FAR: UInt32 = 4096
D3DVIS_OUTSIDE_FAR: UInt32 = 8192
D3DVIS_MASK_FRUSTUM: UInt32 = 3
D3DVIS_MASK_LEFT: UInt32 = 12
D3DVIS_MASK_RIGHT: UInt32 = 48
D3DVIS_MASK_TOP: UInt32 = 192
D3DVIS_MASK_BOTTOM: UInt32 = 768
D3DVIS_MASK_NEAR: UInt32 = 3072
D3DVIS_MASK_FAR: UInt32 = 12288
D3DDEVINFOID_TEXTUREMANAGER: UInt32 = 1
D3DDEVINFOID_D3DTEXTUREMANAGER: UInt32 = 2
D3DDEVINFOID_TEXTURING: UInt32 = 3
@winfunctype('d3d9.dll')
def Direct3DCreate9(SDKVersion: UInt32) -> win32more.Windows.Win32.Graphics.Direct3D9.IDirect3D9: ...
@winfunctype('d3d9.dll')
def D3DPERF_BeginEvent(col: UInt32, wszName: win32more.Windows.Win32.Foundation.PWSTR) -> Int32: ...
@winfunctype('d3d9.dll')
def D3DPERF_EndEvent() -> Int32: ...
@winfunctype('d3d9.dll')
def D3DPERF_SetMarker(col: UInt32, wszName: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
@winfunctype('d3d9.dll')
def D3DPERF_SetRegion(col: UInt32, wszName: win32more.Windows.Win32.Foundation.PWSTR) -> Void: ...
@winfunctype('d3d9.dll')
def D3DPERF_QueryRepeatFrame() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('d3d9.dll')
def D3DPERF_SetOptions(dwOptions: UInt32) -> Void: ...
@winfunctype('d3d9.dll')
def D3DPERF_GetStatus() -> UInt32: ...
@winfunctype('d3d9.dll')
def Direct3DCreate9Ex(SDKVersion: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3D9Ex)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
if ARCH in 'X64,ARM64':
    class D3DADAPTER_IDENTIFIER9(Structure):
        Driver: win32more.Windows.Win32.Foundation.CHAR * 512
        Description: win32more.Windows.Win32.Foundation.CHAR * 512
        DeviceName: win32more.Windows.Win32.Foundation.CHAR * 32
        DriverVersion: Int64
        VendorId: UInt32
        DeviceId: UInt32
        SubSysId: UInt32
        Revision: UInt32
        DeviceIdentifier: Guid
        WHQLLevel: UInt32
elif ARCH in 'X86':
    class D3DADAPTER_IDENTIFIER9(Structure):
        Driver: win32more.Windows.Win32.Foundation.CHAR * 512
        Description: win32more.Windows.Win32.Foundation.CHAR * 512
        DeviceName: win32more.Windows.Win32.Foundation.CHAR * 32
        DriverVersion: Int64
        VendorId: UInt32
        DeviceId: UInt32
        SubSysId: UInt32
        Revision: UInt32
        DeviceIdentifier: Guid
        WHQLLevel: UInt32
        _pack_ = 4
if ARCH in 'X64,ARM64':
    class D3DAES_CTR_IV(Structure):
        IV: UInt64
        Count: UInt64
elif ARCH in 'X86':
    class D3DAES_CTR_IV(Structure):
        IV: UInt64
        Count: UInt64
        _pack_ = 4
D3DANTIALIASMODE = Int32
D3DANTIALIAS_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DANTIALIASMODE = 0
D3DANTIALIAS_SORTDEPENDENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DANTIALIASMODE = 1
D3DANTIALIAS_SORTINDEPENDENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DANTIALIASMODE = 2
D3DAUTHENTICATEDCHANNELTYPE = Int32
D3DAUTHENTICATEDCHANNEL_D3D9: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNELTYPE = 1
D3DAUTHENTICATEDCHANNEL_DRIVER_SOFTWARE: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNELTYPE = 2
D3DAUTHENTICATEDCHANNEL_DRIVER_HARDWARE: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNELTYPE = 3
class D3DAUTHENTICATEDCHANNEL_CONFIGURECRYPTOSESSION(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_CONFIGURE_INPUT
    DXVA2DecodeHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3DAUTHENTICATEDCHANNEL_CONFIGUREINITIALIZE(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_CONFIGURE_INPUT
    StartSequenceQuery: UInt32
    StartSequenceConfigure: UInt32
class D3DAUTHENTICATEDCHANNEL_CONFIGUREPROTECTION(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_CONFIGURE_INPUT
    Protections: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROTECTION_FLAGS
class D3DAUTHENTICATEDCHANNEL_CONFIGURESHAREDRESOURCE(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_CONFIGURE_INPUT
    ProcessIdentiferType: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROCESSIDENTIFIERTYPE
    ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE
    AllowAccess: win32more.Windows.Win32.Foundation.BOOL
class D3DAUTHENTICATEDCHANNEL_CONFIGUREUNCOMPRESSEDENCRYPTION(Structure):
    Parameters: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_CONFIGURE_INPUT
    EncryptionGuid: Guid
class D3DAUTHENTICATEDCHANNEL_CONFIGURE_INPUT(Structure):
    omac: win32more.Windows.Win32.Graphics.Direct3D9.D3D_OMAC
    ConfigureType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
class D3DAUTHENTICATEDCHANNEL_CONFIGURE_OUTPUT(Structure):
    omac: win32more.Windows.Win32.Graphics.Direct3D9.D3D_OMAC
    ConfigureType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
    ReturnCode: win32more.Windows.Win32.Foundation.HRESULT
D3DAUTHENTICATEDCHANNEL_PROCESSIDENTIFIERTYPE = Int32
PROCESSIDTYPE_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROCESSIDENTIFIERTYPE = 0
PROCESSIDTYPE_DWM: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROCESSIDENTIFIERTYPE = 1
PROCESSIDTYPE_HANDLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROCESSIDENTIFIERTYPE = 2
class D3DAUTHENTICATEDCHANNEL_PROTECTION_FLAGS(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        Value: UInt32
        class _Anonymous_e__Struct(Structure):
            ProtectionEnabled: Annotated[UInt32, 1]
            OverlayOrFullscreenRequired: Annotated[UInt32, 1]
            Reserved: Annotated[UInt32, 30]
class D3DAUTHENTICATEDCHANNEL_QUERYCHANNELTYPE_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    ChannelType: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNELTYPE
class D3DAUTHENTICATEDCHANNEL_QUERYCRYPTOSESSION_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_INPUT
    DXVA2DecodeHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3DAUTHENTICATEDCHANNEL_QUERYCRYPTOSESSION_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    DXVA2DecodeHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3DAUTHENTICATEDCHANNEL_QUERYDEVICEHANDLE_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3DAUTHENTICATEDCHANNEL_QUERYEVICTIONENCRYPTIONGUIDCOUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    NumEncryptionGuids: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERYEVICTIONENCRYPTIONGUID_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_INPUT
    EncryptionGuidIndex: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERYEVICTIONENCRYPTIONGUID_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    EncryptionGuidIndex: UInt32
    EncryptionGuid: Guid
class D3DAUTHENTICATEDCHANNEL_QUERYINFOBUSTYPE_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    BusType: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE
    bAccessibleInContiguousBlocks: win32more.Windows.Win32.Foundation.BOOL
    bAccessibleInNonContiguousBlocks: win32more.Windows.Win32.Foundation.BOOL
class D3DAUTHENTICATEDCHANNEL_QUERYOUTPUTIDCOUNT_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_INPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3DAUTHENTICATEDCHANNEL_QUERYOUTPUTIDCOUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    NumOutputIDs: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERYOUTPUTID_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_INPUT
    DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
    CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
    OutputIDIndex: UInt32
if ARCH in 'X64,ARM64':
    class D3DAUTHENTICATEDCHANNEL_QUERYOUTPUTID_OUTPUT(Structure):
        Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
        DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
        CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
        OutputIDIndex: UInt32
        OutputID: UInt64
elif ARCH in 'X86':
    class D3DAUTHENTICATEDCHANNEL_QUERYOUTPUTID_OUTPUT(Structure):
        Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
        DeviceHandle: win32more.Windows.Win32.Foundation.HANDLE
        CryptoSessionHandle: win32more.Windows.Win32.Foundation.HANDLE
        OutputIDIndex: UInt32
        OutputID: UInt64
        _pack_ = 4
class D3DAUTHENTICATEDCHANNEL_QUERYPROTECTION_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    ProtectionFlags: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROTECTION_FLAGS
class D3DAUTHENTICATEDCHANNEL_QUERYRESTRICTEDSHAREDRESOURCEPROCESSCOUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    NumRestrictedSharedResourceProcesses: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERYRESTRICTEDSHAREDRESOURCEPROCESS_INPUT(Structure):
    Input: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_INPUT
    ProcessIndex: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERYRESTRICTEDSHAREDRESOURCEPROCESS_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    ProcessIndex: UInt32
    ProcessIdentifer: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_PROCESSIDENTIFIERTYPE
    ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE
class D3DAUTHENTICATEDCHANNEL_QUERYUNCOMPRESSEDENCRYPTIONLEVEL_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    EncryptionGuid: Guid
class D3DAUTHENTICATEDCHANNEL_QUERYUNRESTRICTEDPROTECTEDSHAREDRESOURCECOUNT_OUTPUT(Structure):
    Output: win32more.Windows.Win32.Graphics.Direct3D9.D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT
    NumUnrestrictedProtectedSharedResources: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERY_INPUT(Structure):
    QueryType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
class D3DAUTHENTICATEDCHANNEL_QUERY_OUTPUT(Structure):
    omac: win32more.Windows.Win32.Graphics.Direct3D9.D3D_OMAC
    QueryType: Guid
    hChannel: win32more.Windows.Win32.Foundation.HANDLE
    SequenceNumber: UInt32
    ReturnCode: win32more.Windows.Win32.Foundation.HRESULT
D3DBACKBUFFER_TYPE = Int32
D3DBACKBUFFER_TYPE_MONO: win32more.Windows.Win32.Graphics.Direct3D9.D3DBACKBUFFER_TYPE = 0
D3DBACKBUFFER_TYPE_LEFT: win32more.Windows.Win32.Graphics.Direct3D9.D3DBACKBUFFER_TYPE = 1
D3DBACKBUFFER_TYPE_RIGHT: win32more.Windows.Win32.Graphics.Direct3D9.D3DBACKBUFFER_TYPE = 2
D3DBASISTYPE = Int32
D3DBASIS_BEZIER: win32more.Windows.Win32.Graphics.Direct3D9.D3DBASISTYPE = 0
D3DBASIS_BSPLINE: win32more.Windows.Win32.Graphics.Direct3D9.D3DBASISTYPE = 1
D3DBASIS_CATMULL_ROM: win32more.Windows.Win32.Graphics.Direct3D9.D3DBASISTYPE = 2
D3DBLEND = Int32
D3DBLEND_ZERO: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 1
D3DBLEND_ONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 2
D3DBLEND_SRCCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 3
D3DBLEND_INVSRCCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 4
D3DBLEND_SRCALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 5
D3DBLEND_INVSRCALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 6
D3DBLEND_DESTALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 7
D3DBLEND_INVDESTALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 8
D3DBLEND_DESTCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 9
D3DBLEND_INVDESTCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 10
D3DBLEND_SRCALPHASAT: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 11
D3DBLEND_BOTHSRCALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 12
D3DBLEND_BOTHINVSRCALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 13
D3DBLEND_BLENDFACTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 14
D3DBLEND_INVBLENDFACTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 15
D3DBLEND_SRCCOLOR2: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 16
D3DBLEND_INVSRCCOLOR2: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLEND = 17
D3DBLENDOP = Int32
D3DBLENDOP_ADD: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLENDOP = 1
D3DBLENDOP_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLENDOP = 2
D3DBLENDOP_REVSUBTRACT: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLENDOP = 3
D3DBLENDOP_MIN: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLENDOP = 4
D3DBLENDOP_MAX: win32more.Windows.Win32.Graphics.Direct3D9.D3DBLENDOP = 5
class D3DBOX(Structure):
    Left: UInt32
    Top: UInt32
    Right: UInt32
    Bottom: UInt32
    Front: UInt32
    Back: UInt32
class D3DBRANCH(Structure):
    dwMask: UInt32
    dwValue: UInt32
    bNegate: win32more.Windows.Win32.Foundation.BOOL
    dwOffset: UInt32
D3DBUSTYPE = Int32
D3DBUSTYPE_OTHER: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 0
D3DBUSTYPE_PCI: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 1
D3DBUSTYPE_PCIX: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 2
D3DBUSTYPE_PCIEXPRESS: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 3
D3DBUSTYPE_AGP: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 4
D3DBUSIMPL_MODIFIER_INSIDE_OF_CHIPSET: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 65536
D3DBUSIMPL_MODIFIER_TRACKS_ON_MOTHER_BOARD_TO_CHIP: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 131072
D3DBUSIMPL_MODIFIER_TRACKS_ON_MOTHER_BOARD_TO_SOCKET: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 196608
D3DBUSIMPL_MODIFIER_DAUGHTER_BOARD_CONNECTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 262144
D3DBUSIMPL_MODIFIER_DAUGHTER_BOARD_CONNECTOR_INSIDE_OF_NUAE: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = 327680
D3DBUSIMPL_MODIFIER_NON_STANDARD: win32more.Windows.Win32.Graphics.Direct3D9.D3DBUSTYPE = -2147483648
class D3DCAPS9(Structure):
    DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE
    AdapterOrdinal: UInt32
    Caps: UInt32
    Caps2: UInt32
    Caps3: UInt32
    PresentationIntervals: UInt32
    CursorCaps: UInt32
    DevCaps: UInt32
    PrimitiveMiscCaps: UInt32
    RasterCaps: UInt32
    ZCmpCaps: UInt32
    SrcBlendCaps: UInt32
    DestBlendCaps: UInt32
    AlphaCmpCaps: UInt32
    ShadeCaps: UInt32
    TextureCaps: UInt32
    TextureFilterCaps: UInt32
    CubeTextureFilterCaps: UInt32
    VolumeTextureFilterCaps: UInt32
    TextureAddressCaps: UInt32
    VolumeTextureAddressCaps: UInt32
    LineCaps: UInt32
    MaxTextureWidth: UInt32
    MaxTextureHeight: UInt32
    MaxVolumeExtent: UInt32
    MaxTextureRepeat: UInt32
    MaxTextureAspectRatio: UInt32
    MaxAnisotropy: UInt32
    MaxVertexW: Single
    GuardBandLeft: Single
    GuardBandTop: Single
    GuardBandRight: Single
    GuardBandBottom: Single
    ExtentsAdjust: Single
    StencilCaps: UInt32
    FVFCaps: UInt32
    TextureOpCaps: UInt32
    MaxTextureBlendStages: UInt32
    MaxSimultaneousTextures: UInt32
    VertexProcessingCaps: UInt32
    MaxActiveLights: UInt32
    MaxUserClipPlanes: UInt32
    MaxVertexBlendMatrices: UInt32
    MaxVertexBlendMatrixIndex: UInt32
    MaxPointSize: Single
    MaxPrimitiveCount: UInt32
    MaxVertexIndex: UInt32
    MaxStreams: UInt32
    MaxStreamStride: UInt32
    VertexShaderVersion: UInt32
    MaxVertexShaderConst: UInt32
    PixelShaderVersion: UInt32
    PixelShader1xMaxValue: Single
    DevCaps2: UInt32
    MaxNpatchTessellationLevel: Single
    Reserved5: UInt32
    MasterAdapterOrdinal: UInt32
    AdapterOrdinalInGroup: UInt32
    NumberOfAdaptersInGroup: UInt32
    DeclTypes: UInt32
    NumSimultaneousRTs: UInt32
    StretchRectFilterCaps: UInt32
    VS20Caps: win32more.Windows.Win32.Graphics.Direct3D9.D3DVSHADERCAPS2_0
    PS20Caps: win32more.Windows.Win32.Graphics.Direct3D9.D3DPSHADERCAPS2_0
    VertexTextureFilterCaps: UInt32
    MaxVShaderInstructionsExecuted: UInt32
    MaxPShaderInstructionsExecuted: UInt32
    MaxVertexShader30InstructionSlots: UInt32
    MaxPixelShader30InstructionSlots: UInt32
class D3DCLIPSTATUS(Structure):
    dwFlags: UInt32
    dwStatus: UInt32
    minx: Single
    maxx: Single
    miny: Single
    maxy: Single
    minz: Single
    maxz: Single
class D3DCLIPSTATUS9(Structure):
    ClipUnion: UInt32
    ClipIntersection: UInt32
D3DCMPFUNC = Int32
D3DCMP_NEVER: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 1
D3DCMP_LESS: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 2
D3DCMP_EQUAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 3
D3DCMP_LESSEQUAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 4
D3DCMP_GREATER: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 5
D3DCMP_NOTEQUAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 6
D3DCMP_GREATEREQUAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 7
D3DCMP_ALWAYS: win32more.Windows.Win32.Graphics.Direct3D9.D3DCMPFUNC = 8
class D3DCOLORVALUE(Structure):
    r: Single
    g: Single
    b: Single
    a: Single
class D3DCOMPOSERECTDESC(Structure):
    X: UInt16
    Y: UInt16
    Width: UInt16
    Height: UInt16
class D3DCOMPOSERECTDESTINATION(Structure):
    SrcRectIndex: UInt16
    Reserved: UInt16
    X: Int16
    Y: Int16
D3DCOMPOSERECTSOP = Int32
D3DCOMPOSERECTS_COPY: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOMPOSERECTSOP = 1
D3DCOMPOSERECTS_OR: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOMPOSERECTSOP = 2
D3DCOMPOSERECTS_AND: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOMPOSERECTSOP = 3
D3DCOMPOSERECTS_NEG: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOMPOSERECTSOP = 4
D3DCUBEMAP_FACES = Int32
D3DCUBEMAP_FACE_POSITIVE_X: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES = 0
D3DCUBEMAP_FACE_NEGATIVE_X: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES = 1
D3DCUBEMAP_FACE_POSITIVE_Y: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES = 2
D3DCUBEMAP_FACE_NEGATIVE_Y: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES = 3
D3DCUBEMAP_FACE_POSITIVE_Z: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES = 4
D3DCUBEMAP_FACE_NEGATIVE_Z: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES = 5
D3DCULL = Int32
D3DCULL_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DCULL = 1
D3DCULL_CW: win32more.Windows.Win32.Graphics.Direct3D9.D3DCULL = 2
D3DCULL_CCW: win32more.Windows.Win32.Graphics.Direct3D9.D3DCULL = 3
D3DDEBUGMONITORTOKENS = Int32
D3DDMT_ENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEBUGMONITORTOKENS = 0
D3DDMT_DISABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEBUGMONITORTOKENS = 1
D3DDECLMETHOD = Int32
D3DDECLMETHOD_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 0
D3DDECLMETHOD_PARTIALU: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 1
D3DDECLMETHOD_PARTIALV: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 2
D3DDECLMETHOD_CROSSUV: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 3
D3DDECLMETHOD_UV: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 4
D3DDECLMETHOD_LOOKUP: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 5
D3DDECLMETHOD_LOOKUPPRESAMPLED: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLMETHOD = 6
D3DDECLTYPE = Int32
D3DDECLTYPE_FLOAT1: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 0
D3DDECLTYPE_FLOAT2: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 1
D3DDECLTYPE_FLOAT3: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 2
D3DDECLTYPE_FLOAT4: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 3
D3DDECLTYPE_D3DCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 4
D3DDECLTYPE_UBYTE4: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 5
D3DDECLTYPE_SHORT2: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 6
D3DDECLTYPE_SHORT4: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 7
D3DDECLTYPE_UBYTE4N: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 8
D3DDECLTYPE_SHORT2N: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 9
D3DDECLTYPE_SHORT4N: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 10
D3DDECLTYPE_USHORT2N: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 11
D3DDECLTYPE_USHORT4N: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 12
D3DDECLTYPE_UDEC3: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 13
D3DDECLTYPE_DEC3N: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 14
D3DDECLTYPE_FLOAT16_2: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 15
D3DDECLTYPE_FLOAT16_4: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 16
D3DDECLTYPE_UNUSED: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLTYPE = 17
D3DDECLUSAGE = Int32
D3DDECLUSAGE_POSITION: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 0
D3DDECLUSAGE_BLENDWEIGHT: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 1
D3DDECLUSAGE_BLENDINDICES: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 2
D3DDECLUSAGE_NORMAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 3
D3DDECLUSAGE_PSIZE: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 4
D3DDECLUSAGE_TEXCOORD: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 5
D3DDECLUSAGE_TANGENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 6
D3DDECLUSAGE_BINORMAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 7
D3DDECLUSAGE_TESSFACTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 8
D3DDECLUSAGE_POSITIONT: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 9
D3DDECLUSAGE_COLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 10
D3DDECLUSAGE_FOG: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 11
D3DDECLUSAGE_DEPTH: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 12
D3DDECLUSAGE_SAMPLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DDECLUSAGE = 13
D3DDEGREETYPE = Int32
D3DDEGREE_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEGREETYPE = 1
D3DDEGREE_QUADRATIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEGREETYPE = 2
D3DDEGREE_CUBIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEGREETYPE = 3
D3DDEGREE_QUINTIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEGREETYPE = 5
class D3DDEVICEDESC(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dcmColorModel: UInt32
    dwDevCaps: UInt32
    dtcTransformCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMCAPS
    bClipping: win32more.Windows.Win32.Foundation.BOOL
    dlcLightingCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTINGCAPS
    dpcLineCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMCAPS
    dpcTriCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMCAPS
    dwDeviceRenderBitDepth: UInt32
    dwDeviceZBufferBitDepth: UInt32
    dwMaxBufferSize: UInt32
    dwMaxVertexCount: UInt32
    dwMinTextureWidth: UInt32
    dwMinTextureHeight: UInt32
    dwMaxTextureWidth: UInt32
    dwMaxTextureHeight: UInt32
    dwMinStippleWidth: UInt32
    dwMaxStippleWidth: UInt32
    dwMinStippleHeight: UInt32
    dwMaxStippleHeight: UInt32
    dwMaxTextureRepeat: UInt32
    dwMaxTextureAspectRatio: UInt32
    dwMaxAnisotropy: UInt32
    dvGuardBandLeft: Single
    dvGuardBandTop: Single
    dvGuardBandRight: Single
    dvGuardBandBottom: Single
    dvExtentsAdjust: Single
    dwStencilCaps: UInt32
    dwFVFCaps: UInt32
    dwTextureOpCaps: UInt32
    wMaxTextureBlendStages: UInt16
    wMaxSimultaneousTextures: UInt16
class D3DDEVICEDESC7(Structure):
    dwDevCaps: UInt32
    dpcLineCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMCAPS
    dpcTriCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMCAPS
    dwDeviceRenderBitDepth: UInt32
    dwDeviceZBufferBitDepth: UInt32
    dwMinTextureWidth: UInt32
    dwMinTextureHeight: UInt32
    dwMaxTextureWidth: UInt32
    dwMaxTextureHeight: UInt32
    dwMaxTextureRepeat: UInt32
    dwMaxTextureAspectRatio: UInt32
    dwMaxAnisotropy: UInt32
    dvGuardBandLeft: Single
    dvGuardBandTop: Single
    dvGuardBandRight: Single
    dvGuardBandBottom: Single
    dvExtentsAdjust: Single
    dwStencilCaps: UInt32
    dwFVFCaps: UInt32
    dwTextureOpCaps: UInt32
    wMaxTextureBlendStages: UInt16
    wMaxSimultaneousTextures: UInt16
    dwMaxActiveLights: UInt32
    dvMaxVertexW: Single
    deviceGUID: Guid
    wMaxUserClipPlanes: UInt16
    wMaxVertexBlendMatrices: UInt16
    dwVertexProcessingCaps: UInt32
    dwReserved1: UInt32
    dwReserved2: UInt32
    dwReserved3: UInt32
    dwReserved4: UInt32
class D3DDEVICE_CREATION_PARAMETERS(Structure):
    AdapterOrdinal: UInt32
    DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE
    hFocusWindow: win32more.Windows.Win32.Foundation.HWND
    BehaviorFlags: UInt32
class D3DDEVINFO_D3D9BANDWIDTHTIMINGS(Structure):
    MaxBandwidthUtilized: Single
    FrontEndUploadMemoryUtilizedPercent: Single
    VertexRateUtilizedPercent: Single
    TriangleSetupRateUtilizedPercent: Single
    FillRateUtilizedPercent: Single
class D3DDEVINFO_D3D9CACHEUTILIZATION(Structure):
    TextureCacheHitRate: Single
    PostTransformVertexCacheHitRate: Single
class D3DDEVINFO_D3D9INTERFACETIMINGS(Structure):
    WaitingForGPUToUseApplicationResourceTimePercent: Single
    WaitingForGPUToAcceptMoreCommandsTimePercent: Single
    WaitingForGPUToStayWithinLatencyTimePercent: Single
    WaitingForGPUExclusiveResourceTimePercent: Single
    WaitingForGPUOtherTimePercent: Single
class D3DDEVINFO_D3D9PIPELINETIMINGS(Structure):
    VertexProcessingTimePercent: Single
    PixelProcessingTimePercent: Single
    OtherGPUProcessingTimePercent: Single
    GPUIdleTimePercent: Single
class D3DDEVINFO_D3D9STAGETIMINGS(Structure):
    MemoryProcessingPercent: Single
    ComputationProcessingPercent: Single
class D3DDEVINFO_D3DVERTEXSTATS(Structure):
    NumRenderedTriangles: UInt32
    NumExtraClippingTriangles: UInt32
class D3DDEVINFO_RESOURCEMANAGER(Structure):
    stats: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCESTATS * 8
class D3DDEVINFO_VCACHE(Structure):
    Pattern: UInt32
    OptMethod: UInt32
    CacheSize: UInt32
    MagicNumber: UInt32
D3DDEVTYPE = Int32
D3DDEVTYPE_HAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE = 1
D3DDEVTYPE_REF: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE = 2
D3DDEVTYPE_SW: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE = 3
D3DDEVTYPE_NULLREF: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE = 4
class D3DDISPLAYMODE(Structure):
    Width: UInt32
    Height: UInt32
    RefreshRate: UInt32
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
class D3DDISPLAYMODEEX(Structure):
    Size: UInt32
    Width: UInt32
    Height: UInt32
    RefreshRate: UInt32
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    ScanLineOrdering: win32more.Windows.Win32.Graphics.Direct3D9.D3DSCANLINEORDERING
class D3DDISPLAYMODEFILTER(Structure):
    Size: UInt32
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    ScanLineOrdering: win32more.Windows.Win32.Graphics.Direct3D9.D3DSCANLINEORDERING
D3DDISPLAYROTATION = Int32
D3DDISPLAYROTATION_IDENTITY: win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION = 1
D3DDISPLAYROTATION_90: win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION = 2
D3DDISPLAYROTATION_180: win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION = 3
D3DDISPLAYROTATION_270: win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION = 4
class D3DDP_PTRSTRIDE(Structure):
    lpvData: VoidPtr
    dwStride: UInt32
class D3DDRAWPRIMITIVESTRIDEDDATA(Structure):
    position: win32more.Windows.Win32.Graphics.Direct3D9.D3DDP_PTRSTRIDE
    normal: win32more.Windows.Win32.Graphics.Direct3D9.D3DDP_PTRSTRIDE
    diffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DDP_PTRSTRIDE
    specular: win32more.Windows.Win32.Graphics.Direct3D9.D3DDP_PTRSTRIDE
    textureCoords: win32more.Windows.Win32.Graphics.Direct3D9.D3DDP_PTRSTRIDE * 8
class D3DENCRYPTED_BLOCK_INFO(Structure):
    NumEncryptedBytesAtBeginning: UInt32
    NumBytesInSkipPattern: UInt32
    NumBytesInEncryptPattern: UInt32
class D3DEXECUTEBUFFERDESC(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    dwCaps: UInt32
    dwBufferSize: UInt32
    lpData: VoidPtr
class D3DEXECUTEDATA(Structure):
    dwSize: UInt32
    dwVertexOffset: UInt32
    dwVertexCount: UInt32
    dwInstructionOffset: UInt32
    dwInstructionLength: UInt32
    dwHVertexOffset: UInt32
    dsStatus: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTATUS
D3DFILLMODE = Int32
D3DFILL_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DFILLMODE = 1
D3DFILL_WIREFRAME: win32more.Windows.Win32.Graphics.Direct3D9.D3DFILLMODE = 2
D3DFILL_SOLID: win32more.Windows.Win32.Graphics.Direct3D9.D3DFILLMODE = 3
class D3DFINDDEVICERESULT(Structure):
    dwSize: UInt32
    guid: Guid
    ddHwDesc: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVICEDESC
    ddSwDesc: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVICEDESC
class D3DFINDDEVICESEARCH(Structure):
    dwSize: UInt32
    dwFlags: UInt32
    bHardware: win32more.Windows.Win32.Foundation.BOOL
    dcmColorModel: UInt32
    guid: Guid
    dwCaps: UInt32
    dpcPrimCaps: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMCAPS
D3DFOGMODE = Int32
D3DFOG_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DFOGMODE = 0
D3DFOG_EXP: win32more.Windows.Win32.Graphics.Direct3D9.D3DFOGMODE = 1
D3DFOG_EXP2: win32more.Windows.Win32.Graphics.Direct3D9.D3DFOGMODE = 2
D3DFOG_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DFOGMODE = 3
D3DFORMAT = UInt32
D3DFMT_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 0
D3DFMT_R8G8B8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 20
D3DFMT_A8R8G8B8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 21
D3DFMT_X8R8G8B8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 22
D3DFMT_R5G6B5: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 23
D3DFMT_X1R5G5B5: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 24
D3DFMT_A1R5G5B5: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 25
D3DFMT_A4R4G4B4: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 26
D3DFMT_R3G3B2: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 27
D3DFMT_A8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 28
D3DFMT_A8R3G3B2: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 29
D3DFMT_X4R4G4B4: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 30
D3DFMT_A2B10G10R10: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 31
D3DFMT_A8B8G8R8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 32
D3DFMT_X8B8G8R8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 33
D3DFMT_G16R16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 34
D3DFMT_A2R10G10B10: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 35
D3DFMT_A16B16G16R16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 36
D3DFMT_A8P8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 40
D3DFMT_P8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 41
D3DFMT_L8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 50
D3DFMT_A8L8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 51
D3DFMT_A4L4: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 52
D3DFMT_V8U8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 60
D3DFMT_L6V5U5: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 61
D3DFMT_X8L8V8U8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 62
D3DFMT_Q8W8V8U8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 63
D3DFMT_V16U16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 64
D3DFMT_A2W10V10U10: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 67
D3DFMT_UYVY: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 1498831189
D3DFMT_R8G8_B8G8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 1195525970
D3DFMT_YUY2: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 844715353
D3DFMT_G8R8_G8B8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 1111970375
D3DFMT_DXT1: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 827611204
D3DFMT_DXT2: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 844388420
D3DFMT_DXT3: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 861165636
D3DFMT_DXT4: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 877942852
D3DFMT_DXT5: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 894720068
D3DFMT_D16_LOCKABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 70
D3DFMT_D32: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 71
D3DFMT_D15S1: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 73
D3DFMT_D24S8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 75
D3DFMT_D24X8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 77
D3DFMT_D24X4S4: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 79
D3DFMT_D16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 80
D3DFMT_D32F_LOCKABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 82
D3DFMT_D24FS8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 83
D3DFMT_D32_LOCKABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 84
D3DFMT_S8_LOCKABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 85
D3DFMT_L16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 81
D3DFMT_VERTEXDATA: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 100
D3DFMT_INDEX16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 101
D3DFMT_INDEX32: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 102
D3DFMT_Q16W16V16U16: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 110
D3DFMT_MULTI2_ARGB8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 827606349
D3DFMT_R16F: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 111
D3DFMT_G16R16F: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 112
D3DFMT_A16B16G16R16F: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 113
D3DFMT_R32F: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 114
D3DFMT_G32R32F: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 115
D3DFMT_A32B32G32R32F: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 116
D3DFMT_CxV8U8: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 117
D3DFMT_A1: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 118
D3DFMT_A2B10G10R10_XR_BIAS: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 119
D3DFMT_BINARYBUFFER: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT = 199
class D3DGAMMARAMP(Structure):
    red: UInt16 * 256
    green: UInt16 * 256
    blue: UInt16 * 256
class D3DHVERTEX(Structure):
    dwFlags: UInt32
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    class _Anonymous1_e__Union(Union):
        hx: Single
        dvHX: Single
    class _Anonymous2_e__Union(Union):
        hy: Single
        dvHY: Single
    class _Anonymous3_e__Union(Union):
        hz: Single
        dvHZ: Single
class D3DINDEXBUFFER_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE
    Usage: UInt32
    Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL
    Size: UInt32
class D3DINSTRUCTION(Structure):
    bOpcode: Byte
    bSize: Byte
    wCount: UInt16
class D3DLIGHT(Structure):
    dwSize: UInt32
    dltType: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE
    dcvColor: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    dvPosition: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvDirection: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvRange: Single
    dvFalloff: Single
    dvAttenuation0: Single
    dvAttenuation1: Single
    dvAttenuation2: Single
    dvTheta: Single
    dvPhi: Single
class D3DLIGHT2(Structure):
    dwSize: UInt32
    dltType: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE
    dcvColor: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    dvPosition: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvDirection: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvRange: Single
    dvFalloff: Single
    dvAttenuation0: Single
    dvAttenuation1: Single
    dvAttenuation2: Single
    dvTheta: Single
    dvPhi: Single
    dwFlags: UInt32
class D3DLIGHT7(Structure):
    dltType: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE
    dcvDiffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    dcvSpecular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    dcvAmbient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    dvPosition: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvDirection: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvRange: Single
    dvFalloff: Single
    dvAttenuation0: Single
    dvAttenuation1: Single
    dvAttenuation2: Single
    dvTheta: Single
    dvPhi: Single
class D3DLIGHT9(Structure):
    Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE
    Diffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Specular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Ambient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Position: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    Direction: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    Range: Single
    Falloff: Single
    Attenuation0: Single
    Attenuation1: Single
    Attenuation2: Single
    Theta: Single
    Phi: Single
class D3DLIGHTDATA(Structure):
    dwSize: UInt32
    lpIn: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTINGELEMENT)
    dwInSize: UInt32
    lpOut: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DTLVERTEX)
    dwOutSize: UInt32
class D3DLIGHTINGCAPS(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwLightingModel: UInt32
    dwNumLights: UInt32
class D3DLIGHTINGELEMENT(Structure):
    dvPosition: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
    dvNormal: win32more.Windows.Win32.Graphics.Direct3D.D3DVECTOR
D3DLIGHTSTATETYPE = Int32
D3DLIGHTSTATE_MATERIAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 1
D3DLIGHTSTATE_AMBIENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 2
D3DLIGHTSTATE_COLORMODEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 3
D3DLIGHTSTATE_FOGMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 4
D3DLIGHTSTATE_FOGSTART: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 5
D3DLIGHTSTATE_FOGEND: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 6
D3DLIGHTSTATE_FOGDENSITY: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 7
D3DLIGHTSTATE_COLORVERTEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE = 8
D3DLIGHTTYPE = Int32
D3DLIGHT_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE = 1
D3DLIGHT_SPOT: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE = 2
D3DLIGHT_DIRECTIONAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTTYPE = 3
class D3DLINE(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        v1: UInt16
        wV1: UInt16
    class _Anonymous2_e__Union(Union):
        v2: UInt16
        wV2: UInt16
class D3DLOCKED_BOX(Structure):
    RowPitch: Int32
    SlicePitch: Int32
    pBits: VoidPtr
class D3DLOCKED_RECT(Structure):
    Pitch: Int32
    pBits: VoidPtr
class D3DLVERTEX(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    dwReserved: UInt32
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    Anonymous6: _Anonymous6_e__Union
    Anonymous7: _Anonymous7_e__Union
    class _Anonymous1_e__Union(Union):
        x: Single
        dvX: Single
    class _Anonymous2_e__Union(Union):
        y: Single
        dvY: Single
    class _Anonymous3_e__Union(Union):
        z: Single
        dvZ: Single
    class _Anonymous4_e__Union(Union):
        color: UInt32
        dcColor: UInt32
    class _Anonymous5_e__Union(Union):
        specular: UInt32
        dcSpecular: UInt32
    class _Anonymous6_e__Union(Union):
        tu: Single
        dvTU: Single
    class _Anonymous7_e__Union(Union):
        tv: Single
        dvTV: Single
class D3DMATERIAL(Structure):
    dwSize: UInt32
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    hTexture: UInt32
    dwRampSize: UInt32
    class _Anonymous1_e__Union(Union):
        diffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvDiffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous2_e__Union(Union):
        ambient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvAmbient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous3_e__Union(Union):
        specular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvSpecular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous4_e__Union(Union):
        emissive: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvEmissive: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous5_e__Union(Union):
        power: Single
        dvPower: Single
class D3DMATERIAL7(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    class _Anonymous1_e__Union(Union):
        diffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvDiffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous2_e__Union(Union):
        ambient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvAmbient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous3_e__Union(Union):
        specular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvSpecular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous4_e__Union(Union):
        emissive: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
        dcvEmissive: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    class _Anonymous5_e__Union(Union):
        power: Single
        dvPower: Single
class D3DMATERIAL9(Structure):
    Diffuse: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Ambient: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Specular: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Emissive: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOLORVALUE
    Power: Single
D3DMATERIALCOLORSOURCE = Int32
D3DMCS_MATERIAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DMATERIALCOLORSOURCE = 0
D3DMCS_COLOR1: win32more.Windows.Win32.Graphics.Direct3D9.D3DMATERIALCOLORSOURCE = 1
D3DMCS_COLOR2: win32more.Windows.Win32.Graphics.Direct3D9.D3DMATERIALCOLORSOURCE = 2
class D3DMATRIXLOAD(Structure):
    hDestMatrix: UInt32
    hSrcMatrix: UInt32
class D3DMATRIXMULTIPLY(Structure):
    hDestMatrix: UInt32
    hSrcMatrix1: UInt32
    hSrcMatrix2: UInt32
if ARCH in 'X64,ARM64':
    class D3DMEMORYPRESSURE(Structure):
        BytesEvictedFromProcess: UInt64
        SizeOfInefficientAllocation: UInt64
        LevelOfEfficiency: UInt32
elif ARCH in 'X86':
    class D3DMEMORYPRESSURE(Structure):
        BytesEvictedFromProcess: UInt64
        SizeOfInefficientAllocation: UInt64
        LevelOfEfficiency: UInt32
        _pack_ = 4
D3DMULTISAMPLE_TYPE = Int32
D3DMULTISAMPLE_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 0
D3DMULTISAMPLE_NONMASKABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 1
D3DMULTISAMPLE_2_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 2
D3DMULTISAMPLE_3_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 3
D3DMULTISAMPLE_4_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 4
D3DMULTISAMPLE_5_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 5
D3DMULTISAMPLE_6_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 6
D3DMULTISAMPLE_7_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 7
D3DMULTISAMPLE_8_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 8
D3DMULTISAMPLE_9_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 9
D3DMULTISAMPLE_10_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 10
D3DMULTISAMPLE_11_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 11
D3DMULTISAMPLE_12_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 12
D3DMULTISAMPLE_13_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 13
D3DMULTISAMPLE_14_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 14
D3DMULTISAMPLE_15_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 15
D3DMULTISAMPLE_16_SAMPLES: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE = 16
D3DOPCODE = Int32
D3DOP_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 1
D3DOP_LINE: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 2
D3DOP_TRIANGLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 3
D3DOP_MATRIXLOAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 4
D3DOP_MATRIXMULTIPLY: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 5
D3DOP_STATETRANSFORM: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 6
D3DOP_STATELIGHT: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 7
D3DOP_STATERENDER: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 8
D3DOP_PROCESSVERTICES: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 9
D3DOP_TEXTURELOAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 10
D3DOP_EXIT: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 11
D3DOP_BRANCHFORWARD: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 12
D3DOP_SPAN: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 13
D3DOP_SETSTATUS: win32more.Windows.Win32.Graphics.Direct3D9.D3DOPCODE = 14
D3DPATCHEDGESTYLE = Int32
D3DPATCHEDGE_DISCRETE: win32more.Windows.Win32.Graphics.Direct3D9.D3DPATCHEDGESTYLE = 0
D3DPATCHEDGE_CONTINUOUS: win32more.Windows.Win32.Graphics.Direct3D9.D3DPATCHEDGESTYLE = 1
class D3DPICKRECORD(Structure):
    bOpcode: Byte
    bPad: Byte
    dwOffset: UInt32
    dvZ: Single
class D3DPOINT(Structure):
    wCount: UInt16
    wFirst: UInt16
D3DPOOL = Int32
D3DPOOL_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL = 0
D3DPOOL_MANAGED: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL = 1
D3DPOOL_SYSTEMMEM: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL = 2
D3DPOOL_SCRATCH: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL = 3
if ARCH in 'X64,ARM64':
    class D3DPRESENTSTATS(Structure):
        PresentCount: UInt32
        PresentRefreshCount: UInt32
        SyncRefreshCount: UInt32
        SyncQPCTime: Int64
        SyncGPUTime: Int64
elif ARCH in 'X86':
    class D3DPRESENTSTATS(Structure):
        PresentCount: UInt32
        PresentRefreshCount: UInt32
        SyncRefreshCount: UInt32
        SyncQPCTime: Int64
        SyncGPUTime: Int64
        _pack_ = 4
class D3DPRESENT_PARAMETERS(Structure):
    BackBufferWidth: UInt32
    BackBufferHeight: UInt32
    BackBufferFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    BackBufferCount: UInt32
    MultiSampleType: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE
    MultiSampleQuality: UInt32
    SwapEffect: win32more.Windows.Win32.Graphics.Direct3D9.D3DSWAPEFFECT
    hDeviceWindow: win32more.Windows.Win32.Foundation.HWND
    Windowed: win32more.Windows.Win32.Foundation.BOOL
    EnableAutoDepthStencil: win32more.Windows.Win32.Foundation.BOOL
    AutoDepthStencilFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    Flags: UInt32
    FullScreen_RefreshRateInHz: UInt32
    PresentationInterval: UInt32
class D3DPRIMCAPS(Structure):
    dwSize: UInt32
    dwMiscCaps: UInt32
    dwRasterCaps: UInt32
    dwZCmpCaps: UInt32
    dwSrcBlendCaps: UInt32
    dwDestBlendCaps: UInt32
    dwAlphaCmpCaps: UInt32
    dwShadeCaps: UInt32
    dwTextureCaps: UInt32
    dwTextureFilterCaps: UInt32
    dwTextureBlendCaps: UInt32
    dwTextureAddressCaps: UInt32
    dwStippleWidth: UInt32
    dwStippleHeight: UInt32
D3DPRIMITIVETYPE = Int32
D3DPT_POINTLIST: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE = 1
D3DPT_LINELIST: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE = 2
D3DPT_LINESTRIP: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE = 3
D3DPT_TRIANGLELIST: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE = 4
D3DPT_TRIANGLESTRIP: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE = 5
D3DPT_TRIANGLEFAN: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE = 6
class D3DPROCESSVERTICES(Structure):
    dwFlags: UInt32
    wStart: UInt16
    wDest: UInt16
    dwCount: UInt32
    dwReserved: UInt32
class D3DPSHADERCAPS2_0(Structure):
    Caps: UInt32
    DynamicFlowControlDepth: Int32
    NumTemps: Int32
    StaticFlowControlDepth: Int32
    NumInstructionSlots: Int32
D3DQUERYTYPE = Int32
D3DQUERYTYPE_VCACHE: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 4
D3DQUERYTYPE_RESOURCEMANAGER: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 5
D3DQUERYTYPE_VERTEXSTATS: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 6
D3DQUERYTYPE_EVENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 8
D3DQUERYTYPE_OCCLUSION: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 9
D3DQUERYTYPE_TIMESTAMP: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 10
D3DQUERYTYPE_TIMESTAMPDISJOINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 11
D3DQUERYTYPE_TIMESTAMPFREQ: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 12
D3DQUERYTYPE_PIPELINETIMINGS: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 13
D3DQUERYTYPE_INTERFACETIMINGS: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 14
D3DQUERYTYPE_VERTEXTIMINGS: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 15
D3DQUERYTYPE_PIXELTIMINGS: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 16
D3DQUERYTYPE_BANDWIDTHTIMINGS: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 17
D3DQUERYTYPE_CACHEUTILIZATION: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 18
D3DQUERYTYPE_MEMORYPRESSURE: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE = 19
class D3DRANGE(Structure):
    Offset: UInt32
    Size: UInt32
class D3DRASTER_STATUS(Structure):
    InVBlank: win32more.Windows.Win32.Foundation.BOOL
    ScanLine: UInt32
class D3DRECT(Structure):
    x1: Int32
    y1: Int32
    x2: Int32
    y2: Int32
class D3DRECTPATCH_INFO(Structure):
    StartVertexOffsetWidth: UInt32
    StartVertexOffsetHeight: UInt32
    Width: UInt32
    Height: UInt32
    Stride: UInt32
    Basis: win32more.Windows.Win32.Graphics.Direct3D9.D3DBASISTYPE
    Degree: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEGREETYPE
D3DRENDERSTATETYPE = Int32
D3DRS_ZENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 7
D3DRS_FILLMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 8
D3DRS_SHADEMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 9
D3DRS_ZWRITEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 14
D3DRS_ALPHATESTENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 15
D3DRS_LASTPIXEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 16
D3DRS_SRCBLEND: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 19
D3DRS_DESTBLEND: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 20
D3DRS_CULLMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 22
D3DRS_ZFUNC: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 23
D3DRS_ALPHAREF: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 24
D3DRS_ALPHAFUNC: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 25
D3DRS_DITHERENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 26
D3DRS_ALPHABLENDENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 27
D3DRS_FOGENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 28
D3DRS_SPECULARENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 29
D3DRS_FOGCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 34
D3DRS_FOGTABLEMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 35
D3DRS_FOGSTART: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 36
D3DRS_FOGEND: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 37
D3DRS_FOGDENSITY: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 38
D3DRS_RANGEFOGENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 48
D3DRS_STENCILENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 52
D3DRS_STENCILFAIL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 53
D3DRS_STENCILZFAIL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 54
D3DRS_STENCILPASS: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 55
D3DRS_STENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 56
D3DRS_STENCILREF: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 57
D3DRS_STENCILMASK: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 58
D3DRS_STENCILWRITEMASK: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 59
D3DRS_TEXTUREFACTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 60
D3DRS_WRAP0: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 128
D3DRS_WRAP1: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 129
D3DRS_WRAP2: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 130
D3DRS_WRAP3: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 131
D3DRS_WRAP4: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 132
D3DRS_WRAP5: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 133
D3DRS_WRAP6: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 134
D3DRS_WRAP7: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 135
D3DRS_CLIPPING: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 136
D3DRS_LIGHTING: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 137
D3DRS_AMBIENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 139
D3DRS_FOGVERTEXMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 140
D3DRS_COLORVERTEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 141
D3DRS_LOCALVIEWER: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 142
D3DRS_NORMALIZENORMALS: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 143
D3DRS_DIFFUSEMATERIALSOURCE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 145
D3DRS_SPECULARMATERIALSOURCE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 146
D3DRS_AMBIENTMATERIALSOURCE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 147
D3DRS_EMISSIVEMATERIALSOURCE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 148
D3DRS_VERTEXBLEND: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 151
D3DRS_CLIPPLANEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 152
D3DRS_POINTSIZE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 154
D3DRS_POINTSIZE_MIN: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 155
D3DRS_POINTSPRITEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 156
D3DRS_POINTSCALEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 157
D3DRS_POINTSCALE_A: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 158
D3DRS_POINTSCALE_B: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 159
D3DRS_POINTSCALE_C: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 160
D3DRS_MULTISAMPLEANTIALIAS: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 161
D3DRS_MULTISAMPLEMASK: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 162
D3DRS_PATCHEDGESTYLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 163
D3DRS_DEBUGMONITORTOKEN: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 165
D3DRS_POINTSIZE_MAX: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 166
D3DRS_INDEXEDVERTEXBLENDENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 167
D3DRS_COLORWRITEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 168
D3DRS_TWEENFACTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 170
D3DRS_BLENDOP: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 171
D3DRS_POSITIONDEGREE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 172
D3DRS_NORMALDEGREE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 173
D3DRS_SCISSORTESTENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 174
D3DRS_SLOPESCALEDEPTHBIAS: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 175
D3DRS_ANTIALIASEDLINEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 176
D3DRS_MINTESSELLATIONLEVEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 178
D3DRS_MAXTESSELLATIONLEVEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 179
D3DRS_ADAPTIVETESS_X: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 180
D3DRS_ADAPTIVETESS_Y: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 181
D3DRS_ADAPTIVETESS_Z: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 182
D3DRS_ADAPTIVETESS_W: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 183
D3DRS_ENABLEADAPTIVETESSELLATION: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 184
D3DRS_TWOSIDEDSTENCILMODE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 185
D3DRS_CCW_STENCILFAIL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 186
D3DRS_CCW_STENCILZFAIL: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 187
D3DRS_CCW_STENCILPASS: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 188
D3DRS_CCW_STENCILFUNC: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 189
D3DRS_COLORWRITEENABLE1: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 190
D3DRS_COLORWRITEENABLE2: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 191
D3DRS_COLORWRITEENABLE3: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 192
D3DRS_BLENDFACTOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 193
D3DRS_SRGBWRITEENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 194
D3DRS_DEPTHBIAS: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 195
D3DRS_WRAP8: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 198
D3DRS_WRAP9: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 199
D3DRS_WRAP10: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 200
D3DRS_WRAP11: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 201
D3DRS_WRAP12: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 202
D3DRS_WRAP13: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 203
D3DRS_WRAP14: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 204
D3DRS_WRAP15: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 205
D3DRS_SEPARATEALPHABLENDENABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 206
D3DRS_SRCBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 207
D3DRS_DESTBLENDALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 208
D3DRS_BLENDOPALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE = 209
class D3DRESOURCESTATS(Structure):
    bThrashing: win32more.Windows.Win32.Foundation.BOOL
    ApproxBytesDownloaded: UInt32
    NumEvicts: UInt32
    NumVidCreates: UInt32
    LastPri: UInt32
    NumUsed: UInt32
    NumUsedInVidMem: UInt32
    WorkingSet: UInt32
    WorkingSetBytes: UInt32
    TotalManaged: UInt32
    TotalBytes: UInt32
D3DRESOURCETYPE = Int32
D3DRTYPE_SURFACE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 1
D3DRTYPE_VOLUME: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 2
D3DRTYPE_TEXTURE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 3
D3DRTYPE_VOLUMETEXTURE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 4
D3DRTYPE_CUBETEXTURE: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 5
D3DRTYPE_VERTEXBUFFER: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 6
D3DRTYPE_INDEXBUFFER: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE = 7
D3DSAMPLERSTATETYPE = Int32
D3DSAMP_ADDRESSU: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 1
D3DSAMP_ADDRESSV: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 2
D3DSAMP_ADDRESSW: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 3
D3DSAMP_BORDERCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 4
D3DSAMP_MAGFILTER: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 5
D3DSAMP_MINFILTER: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 6
D3DSAMP_MIPFILTER: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 7
D3DSAMP_MIPMAPLODBIAS: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 8
D3DSAMP_MAXMIPLEVEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 9
D3DSAMP_MAXANISOTROPY: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 10
D3DSAMP_SRGBTEXTURE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 11
D3DSAMP_ELEMENTINDEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 12
D3DSAMP_DMAPOFFSET: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE = 13
D3DSAMPLER_TEXTURE_TYPE = Int32
D3DSTT_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLER_TEXTURE_TYPE = 0
D3DSTT_2D: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLER_TEXTURE_TYPE = 268435456
D3DSTT_CUBE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLER_TEXTURE_TYPE = 402653184
D3DSTT_VOLUME: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLER_TEXTURE_TYPE = 536870912
D3DSCANLINEORDERING = Int32
D3DSCANLINEORDERING_UNKNOWN: win32more.Windows.Win32.Graphics.Direct3D9.D3DSCANLINEORDERING = 0
D3DSCANLINEORDERING_PROGRESSIVE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSCANLINEORDERING = 1
D3DSCANLINEORDERING_INTERLACED: win32more.Windows.Win32.Graphics.Direct3D9.D3DSCANLINEORDERING = 2
D3DSHADEMODE = Int32
D3DSHADE_FLAT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADEMODE = 1
D3DSHADE_GOURAUD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADEMODE = 2
D3DSHADE_PHONG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADEMODE = 3
D3DSHADER_ADDRESSMODE_TYPE = Int32
D3DSHADER_ADDRMODE_ABSOLUTE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_ADDRESSMODE_TYPE = 0
D3DSHADER_ADDRMODE_RELATIVE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_ADDRESSMODE_TYPE = 8192
D3DSHADER_COMPARISON = Int32
D3DSPC_RESERVED0: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 0
D3DSPC_GT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 1
D3DSPC_EQ: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 2
D3DSPC_GE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 3
D3DSPC_LT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 4
D3DSPC_NE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 5
D3DSPC_LE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 6
D3DSPC_RESERVED1: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_COMPARISON = 7
D3DSHADER_INSTRUCTION_OPCODE_TYPE = Int32
D3DSIO_NOP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 0
D3DSIO_MOV: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 1
D3DSIO_ADD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 2
D3DSIO_SUB: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 3
D3DSIO_MAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 4
D3DSIO_MUL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 5
D3DSIO_RCP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 6
D3DSIO_RSQ: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 7
D3DSIO_DP3: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 8
D3DSIO_DP4: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 9
D3DSIO_MIN: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 10
D3DSIO_MAX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 11
D3DSIO_SLT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 12
D3DSIO_SGE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 13
D3DSIO_EXP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 14
D3DSIO_LOG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 15
D3DSIO_LIT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 16
D3DSIO_DST: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 17
D3DSIO_LRP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 18
D3DSIO_FRC: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 19
D3DSIO_M4x4: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 20
D3DSIO_M4x3: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 21
D3DSIO_M3x4: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 22
D3DSIO_M3x3: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 23
D3DSIO_M3x2: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 24
D3DSIO_CALL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 25
D3DSIO_CALLNZ: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 26
D3DSIO_LOOP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 27
D3DSIO_RET: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 28
D3DSIO_ENDLOOP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 29
D3DSIO_LABEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 30
D3DSIO_DCL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 31
D3DSIO_POW: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 32
D3DSIO_CRS: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 33
D3DSIO_SGN: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 34
D3DSIO_ABS: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 35
D3DSIO_NRM: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 36
D3DSIO_SINCOS: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 37
D3DSIO_REP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 38
D3DSIO_ENDREP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 39
D3DSIO_IF: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 40
D3DSIO_IFC: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 41
D3DSIO_ELSE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 42
D3DSIO_ENDIF: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 43
D3DSIO_BREAK: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 44
D3DSIO_BREAKC: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 45
D3DSIO_MOVA: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 46
D3DSIO_DEFB: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 47
D3DSIO_DEFI: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 48
D3DSIO_TEXCOORD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 64
D3DSIO_TEXKILL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 65
D3DSIO_TEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 66
D3DSIO_TEXBEM: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 67
D3DSIO_TEXBEML: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 68
D3DSIO_TEXREG2AR: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 69
D3DSIO_TEXREG2GB: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 70
D3DSIO_TEXM3x2PAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 71
D3DSIO_TEXM3x2TEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 72
D3DSIO_TEXM3x3PAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 73
D3DSIO_TEXM3x3TEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 74
D3DSIO_RESERVED0: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 75
D3DSIO_TEXM3x3SPEC: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 76
D3DSIO_TEXM3x3VSPEC: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 77
D3DSIO_EXPP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 78
D3DSIO_LOGP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 79
D3DSIO_CND: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 80
D3DSIO_DEF: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 81
D3DSIO_TEXREG2RGB: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 82
D3DSIO_TEXDP3TEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 83
D3DSIO_TEXM3x2DEPTH: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 84
D3DSIO_TEXDP3: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 85
D3DSIO_TEXM3x3: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 86
D3DSIO_TEXDEPTH: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 87
D3DSIO_CMP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 88
D3DSIO_BEM: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 89
D3DSIO_DP2ADD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 90
D3DSIO_DSX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 91
D3DSIO_DSY: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 92
D3DSIO_TEXLDD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 93
D3DSIO_SETP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 94
D3DSIO_TEXLDL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 95
D3DSIO_BREAKP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 96
D3DSIO_PHASE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 65533
D3DSIO_COMMENT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 65534
D3DSIO_END: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_INSTRUCTION_OPCODE_TYPE = 65535
D3DSHADER_MIN_PRECISION = Int32
D3DMP_DEFAULT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_MIN_PRECISION = 0
D3DMP_16: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_MIN_PRECISION = 1
D3DMP_2_8: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_MIN_PRECISION = 2
D3DSHADER_MISCTYPE_OFFSETS = Int32
D3DSMO_POSITION: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_MISCTYPE_OFFSETS = 0
D3DSMO_FACE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_MISCTYPE_OFFSETS = 1
D3DSHADER_PARAM_REGISTER_TYPE = Int32
D3DSPR_TEMP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 0
D3DSPR_INPUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 1
D3DSPR_CONST: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 2
D3DSPR_ADDR: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 3
D3DSPR_TEXTURE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 3
D3DSPR_RASTOUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 4
D3DSPR_ATTROUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 5
D3DSPR_TEXCRDOUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 6
D3DSPR_OUTPUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 6
D3DSPR_CONSTINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 7
D3DSPR_COLOROUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 8
D3DSPR_DEPTHOUT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 9
D3DSPR_SAMPLER: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 10
D3DSPR_CONST2: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 11
D3DSPR_CONST3: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 12
D3DSPR_CONST4: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 13
D3DSPR_CONSTBOOL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 14
D3DSPR_LOOP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 15
D3DSPR_TEMPFLOAT16: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 16
D3DSPR_MISCTYPE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 17
D3DSPR_LABEL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 18
D3DSPR_PREDICATE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_REGISTER_TYPE = 19
D3DSHADER_PARAM_SRCMOD_TYPE = Int32
D3DSPSM_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 0
D3DSPSM_NEG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 16777216
D3DSPSM_BIAS: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 33554432
D3DSPSM_BIASNEG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 50331648
D3DSPSM_SIGN: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 67108864
D3DSPSM_SIGNNEG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 83886080
D3DSPSM_COMP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 100663296
D3DSPSM_X2: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 117440512
D3DSPSM_X2NEG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 134217728
D3DSPSM_DZ: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 150994944
D3DSPSM_DW: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 167772160
D3DSPSM_ABS: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 184549376
D3DSPSM_ABSNEG: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 201326592
D3DSPSM_NOT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSHADER_PARAM_SRCMOD_TYPE = 218103808
class D3DSPAN(Structure):
    wCount: UInt16
    wFirst: UInt16
class D3DSTATE(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        dlstLightStateType: win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHTSTATETYPE
        drstRenderStateType: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE
    class _Anonymous2_e__Union(Union):
        dwArg: UInt32 * 1
        dvArg: Single * 1
D3DSTATEBLOCKTYPE = Int32
D3DSBT_ALL: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTATEBLOCKTYPE = 1
D3DSBT_PIXELSTATE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTATEBLOCKTYPE = 2
D3DSBT_VERTEXSTATE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTATEBLOCKTYPE = 3
class D3DSTATS(Structure):
    dwSize: UInt32
    dwTrianglesDrawn: UInt32
    dwLinesDrawn: UInt32
    dwPointsDrawn: UInt32
    dwSpansDrawn: UInt32
    dwVerticesProcessed: UInt32
class D3DSTATUS(Structure):
    dwFlags: UInt32
    dwStatus: UInt32
    drExtent: win32more.Windows.Win32.Graphics.Direct3D9.D3DRECT
D3DSTENCILOP = Int32
D3DSTENCILOP_KEEP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 1
D3DSTENCILOP_ZERO: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 2
D3DSTENCILOP_REPLACE: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 3
D3DSTENCILOP_INCRSAT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 4
D3DSTENCILOP_DECRSAT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 5
D3DSTENCILOP_INVERT: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 6
D3DSTENCILOP_INCR: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 7
D3DSTENCILOP_DECR: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTENCILOP = 8
class D3DSURFACE_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE
    Usage: UInt32
    Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL
    MultiSampleType: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE
    MultiSampleQuality: UInt32
    Width: UInt32
    Height: UInt32
D3DSWAPEFFECT = Int32
D3DSWAPEFFECT_DISCARD: win32more.Windows.Win32.Graphics.Direct3D9.D3DSWAPEFFECT = 1
D3DSWAPEFFECT_FLIP: win32more.Windows.Win32.Graphics.Direct3D9.D3DSWAPEFFECT = 2
D3DSWAPEFFECT_COPY: win32more.Windows.Win32.Graphics.Direct3D9.D3DSWAPEFFECT = 3
D3DSWAPEFFECT_OVERLAY: win32more.Windows.Win32.Graphics.Direct3D9.D3DSWAPEFFECT = 4
D3DSWAPEFFECT_FLIPEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DSWAPEFFECT = 5
D3DTEXTUREADDRESS = Int32
D3DTADDRESS_WRAP: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREADDRESS = 1
D3DTADDRESS_MIRROR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREADDRESS = 2
D3DTADDRESS_CLAMP: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREADDRESS = 3
D3DTADDRESS_BORDER: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREADDRESS = 4
D3DTADDRESS_MIRRORONCE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREADDRESS = 5
D3DTEXTUREBLEND = Int32
D3DTBLEND_DECAL: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 1
D3DTBLEND_MODULATE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 2
D3DTBLEND_DECALALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 3
D3DTBLEND_MODULATEALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 4
D3DTBLEND_DECALMASK: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 5
D3DTBLEND_MODULATEMASK: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 6
D3DTBLEND_COPY: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 7
D3DTBLEND_ADD: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREBLEND = 8
D3DTEXTUREFILTER = Int32
D3DFILTER_NEAREST: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTER = 1
D3DFILTER_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTER = 2
D3DFILTER_MIPNEAREST: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTER = 3
D3DFILTER_MIPLINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTER = 4
D3DFILTER_LINEARMIPNEAREST: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTER = 5
D3DFILTER_LINEARMIPLINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTER = 6
D3DTEXTUREFILTERTYPE = Int32
D3DTEXF_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 0
D3DTEXF_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 1
D3DTEXF_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 2
D3DTEXF_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 3
D3DTEXF_PYRAMIDALQUAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 6
D3DTEXF_GAUSSIANQUAD: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 7
D3DTEXF_CONVOLUTIONMONO: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE = 8
class D3DTEXTURELOAD(Structure):
    hDestTexture: UInt32
    hSrcTexture: UInt32
D3DTEXTUREMAGFILTER = Int32
D3DTFG_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMAGFILTER = 1
D3DTFG_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMAGFILTER = 2
D3DTFG_FLATCUBIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMAGFILTER = 3
D3DTFG_GAUSSIANCUBIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMAGFILTER = 4
D3DTFG_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMAGFILTER = 5
D3DTEXTUREMINFILTER = Int32
D3DTFN_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMINFILTER = 1
D3DTFN_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMINFILTER = 2
D3DTFN_ANISOTROPIC: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMINFILTER = 3
D3DTEXTUREMIPFILTER = Int32
D3DTFP_NONE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMIPFILTER = 1
D3DTFP_POINT: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMIPFILTER = 2
D3DTFP_LINEAR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREMIPFILTER = 3
D3DTEXTUREOP = Int32
D3DTOP_DISABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 1
D3DTOP_SELECTARG1: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 2
D3DTOP_SELECTARG2: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 3
D3DTOP_MODULATE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 4
D3DTOP_MODULATE2X: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 5
D3DTOP_MODULATE4X: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 6
D3DTOP_ADD: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 7
D3DTOP_ADDSIGNED: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 8
D3DTOP_ADDSIGNED2X: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 9
D3DTOP_SUBTRACT: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 10
D3DTOP_ADDSMOOTH: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 11
D3DTOP_BLENDDIFFUSEALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 12
D3DTOP_BLENDTEXTUREALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 13
D3DTOP_BLENDFACTORALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 14
D3DTOP_BLENDTEXTUREALPHAPM: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 15
D3DTOP_BLENDCURRENTALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 16
D3DTOP_PREMODULATE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 17
D3DTOP_MODULATEALPHA_ADDCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 18
D3DTOP_MODULATECOLOR_ADDALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 19
D3DTOP_MODULATEINVALPHA_ADDCOLOR: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 20
D3DTOP_MODULATEINVCOLOR_ADDALPHA: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 21
D3DTOP_BUMPENVMAP: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 22
D3DTOP_BUMPENVMAPLUMINANCE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 23
D3DTOP_DOTPRODUCT3: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 24
D3DTOP_MULTIPLYADD: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 25
D3DTOP_LERP: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREOP = 26
D3DTEXTURESTAGESTATETYPE = Int32
D3DTSS_COLOROP: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 1
D3DTSS_COLORARG1: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 2
D3DTSS_COLORARG2: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 3
D3DTSS_ALPHAOP: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 4
D3DTSS_ALPHAARG1: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 5
D3DTSS_ALPHAARG2: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 6
D3DTSS_BUMPENVMAT00: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 7
D3DTSS_BUMPENVMAT01: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 8
D3DTSS_BUMPENVMAT10: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 9
D3DTSS_BUMPENVMAT11: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 10
D3DTSS_TEXCOORDINDEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 11
D3DTSS_BUMPENVLSCALE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 22
D3DTSS_BUMPENVLOFFSET: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 23
D3DTSS_TEXTURETRANSFORMFLAGS: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 24
D3DTSS_COLORARG0: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 26
D3DTSS_ALPHAARG0: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 27
D3DTSS_RESULTARG: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 28
D3DTSS_CONSTANT: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE = 32
D3DTEXTURETRANSFORMFLAGS = Int32
D3DTTFF_DISABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURETRANSFORMFLAGS = 0
D3DTTFF_COUNT1: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURETRANSFORMFLAGS = 1
D3DTTFF_COUNT2: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURETRANSFORMFLAGS = 2
D3DTTFF_COUNT3: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURETRANSFORMFLAGS = 3
D3DTTFF_COUNT4: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURETRANSFORMFLAGS = 4
D3DTTFF_PROJECTED: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURETRANSFORMFLAGS = 256
class D3DTLVERTEX(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    Anonymous6: _Anonymous6_e__Union
    Anonymous7: _Anonymous7_e__Union
    Anonymous8: _Anonymous8_e__Union
    class _Anonymous1_e__Union(Union):
        sx: Single
        dvSX: Single
    class _Anonymous2_e__Union(Union):
        sy: Single
        dvSY: Single
    class _Anonymous3_e__Union(Union):
        sz: Single
        dvSZ: Single
    class _Anonymous4_e__Union(Union):
        rhw: Single
        dvRHW: Single
    class _Anonymous5_e__Union(Union):
        color: UInt32
        dcColor: UInt32
    class _Anonymous6_e__Union(Union):
        specular: UInt32
        dcSpecular: UInt32
    class _Anonymous7_e__Union(Union):
        tu: Single
        dvTU: Single
    class _Anonymous8_e__Union(Union):
        tv: Single
        dvTV: Single
class D3DTRANSFORMCAPS(Structure):
    dwSize: UInt32
    dwCaps: UInt32
class D3DTRANSFORMDATA(Structure):
    dwSize: UInt32
    lpIn: VoidPtr
    dwInSize: UInt32
    lpOut: VoidPtr
    dwOutSize: UInt32
    lpHOut: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DHVERTEX)
    dwClip: UInt32
    dwClipIntersection: UInt32
    dwClipUnion: UInt32
    drExtent: win32more.Windows.Win32.Graphics.Direct3D9.D3DRECT
D3DTRANSFORMSTATETYPE = Int32
D3DTS_VIEW: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 2
D3DTS_PROJECTION: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 3
D3DTS_TEXTURE0: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 16
D3DTS_TEXTURE1: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 17
D3DTS_TEXTURE2: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 18
D3DTS_TEXTURE3: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 19
D3DTS_TEXTURE4: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 20
D3DTS_TEXTURE5: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 21
D3DTS_TEXTURE6: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 22
D3DTS_TEXTURE7: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE = 23
class D3DTRIANGLE(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    wFlags: UInt16
    class _Anonymous1_e__Union(Union):
        v1: UInt16
        wV1: UInt16
    class _Anonymous2_e__Union(Union):
        v2: UInt16
        wV2: UInt16
    class _Anonymous3_e__Union(Union):
        v3: UInt16
        wV3: UInt16
class D3DTRIPATCH_INFO(Structure):
    StartVertexOffset: UInt32
    NumVertices: UInt32
    Basis: win32more.Windows.Win32.Graphics.Direct3D9.D3DBASISTYPE
    Degree: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEGREETYPE
class D3DVERTEX(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    Anonymous3: _Anonymous3_e__Union
    Anonymous4: _Anonymous4_e__Union
    Anonymous5: _Anonymous5_e__Union
    Anonymous6: _Anonymous6_e__Union
    Anonymous7: _Anonymous7_e__Union
    Anonymous8: _Anonymous8_e__Union
    class _Anonymous1_e__Union(Union):
        x: Single
        dvX: Single
    class _Anonymous2_e__Union(Union):
        y: Single
        dvY: Single
    class _Anonymous3_e__Union(Union):
        z: Single
        dvZ: Single
    class _Anonymous4_e__Union(Union):
        nx: Single
        dvNX: Single
    class _Anonymous5_e__Union(Union):
        ny: Single
        dvNY: Single
    class _Anonymous6_e__Union(Union):
        nz: Single
        dvNZ: Single
    class _Anonymous7_e__Union(Union):
        tu: Single
        dvTU: Single
    class _Anonymous8_e__Union(Union):
        tv: Single
        dvTV: Single
D3DVERTEXBLENDFLAGS = Int32
D3DVBF_DISABLE: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBLENDFLAGS = 0
D3DVBF_1WEIGHTS: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBLENDFLAGS = 1
D3DVBF_2WEIGHTS: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBLENDFLAGS = 2
D3DVBF_3WEIGHTS: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBLENDFLAGS = 3
D3DVBF_TWEENING: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBLENDFLAGS = 255
D3DVBF_0WEIGHTS: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBLENDFLAGS = 256
class D3DVERTEXBUFFERDESC(Structure):
    dwSize: UInt32
    dwCaps: UInt32
    dwFVF: UInt32
    dwNumVertices: UInt32
class D3DVERTEXBUFFER_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE
    Usage: UInt32
    Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL
    Size: UInt32
    FVF: UInt32
class D3DVERTEXELEMENT9(Structure):
    Stream: UInt16
    Offset: UInt16
    Type: Byte
    Method: Byte
    Usage: Byte
    UsageIndex: Byte
D3DVERTEXTYPE = Int32
D3DVT_VERTEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXTYPE = 1
D3DVT_LVERTEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXTYPE = 2
D3DVT_TLVERTEX: win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXTYPE = 3
class D3DVIEWPORT(Structure):
    dwSize: UInt32
    dwX: UInt32
    dwY: UInt32
    dwWidth: UInt32
    dwHeight: UInt32
    dvScaleX: Single
    dvScaleY: Single
    dvMaxX: Single
    dvMaxY: Single
    dvMinZ: Single
    dvMaxZ: Single
class D3DVIEWPORT2(Structure):
    dwSize: UInt32
    dwX: UInt32
    dwY: UInt32
    dwWidth: UInt32
    dwHeight: UInt32
    dvClipX: Single
    dvClipY: Single
    dvClipWidth: Single
    dvClipHeight: Single
    dvMinZ: Single
    dvMaxZ: Single
class D3DVIEWPORT7(Structure):
    dwX: UInt32
    dwY: UInt32
    dwWidth: UInt32
    dwHeight: UInt32
    dvMinZ: Single
    dvMaxZ: Single
class D3DVIEWPORT9(Structure):
    X: UInt32
    Y: UInt32
    Width: UInt32
    Height: UInt32
    MinZ: Single
    MaxZ: Single
class D3DVOLUME_DESC(Structure):
    Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT
    Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE
    Usage: UInt32
    Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL
    Width: UInt32
    Height: UInt32
    Depth: UInt32
class D3DVSHADERCAPS2_0(Structure):
    Caps: UInt32
    DynamicFlowControlDepth: Int32
    NumTemps: Int32
    StaticFlowControlDepth: Int32
D3DVS_ADDRESSMODE_TYPE = Int32
D3DVS_ADDRMODE_ABSOLUTE: win32more.Windows.Win32.Graphics.Direct3D9.D3DVS_ADDRESSMODE_TYPE = 0
D3DVS_ADDRMODE_RELATIVE: win32more.Windows.Win32.Graphics.Direct3D9.D3DVS_ADDRESSMODE_TYPE = 8192
D3DVS_RASTOUT_OFFSETS = Int32
D3DSRO_POSITION: win32more.Windows.Win32.Graphics.Direct3D9.D3DVS_RASTOUT_OFFSETS = 0
D3DSRO_FOG: win32more.Windows.Win32.Graphics.Direct3D9.D3DVS_RASTOUT_OFFSETS = 1
D3DSRO_POINT_SIZE: win32more.Windows.Win32.Graphics.Direct3D9.D3DVS_RASTOUT_OFFSETS = 2
D3DZBUFFERTYPE = Int32
D3DZB_FALSE: win32more.Windows.Win32.Graphics.Direct3D9.D3DZBUFFERTYPE = 0
D3DZB_TRUE: win32more.Windows.Win32.Graphics.Direct3D9.D3DZBUFFERTYPE = 1
D3DZB_USEW: win32more.Windows.Win32.Graphics.Direct3D9.D3DZBUFFERTYPE = 2
class D3D_OMAC(Structure):
    Omac: Byte * 16
class IDirect3D9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{81bdcbca-64d4-426d-ae8d-ad0147f4275c}')
    @commethod(3)
    def RegisterSoftwareDevice(self, pInitializeFunction: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAdapterCount(self) -> UInt32: ...
    @commethod(5)
    def GetAdapterIdentifier(self, Adapter: UInt32, Flags: UInt32, pIdentifier: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DADAPTER_IDENTIFIER9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetAdapterModeCount(self, Adapter: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT) -> UInt32: ...
    @commethod(7)
    def EnumAdapterModes(self, Adapter: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Mode: UInt32, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetAdapterDisplayMode(self, Adapter: UInt32, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CheckDeviceType(self, Adapter: UInt32, DevType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, AdapterFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, BackBufferFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, bWindowed: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CheckDeviceFormat(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, AdapterFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Usage: UInt32, RType: win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE, CheckFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def CheckDeviceMultiSampleType(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, SurfaceFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Windowed: win32more.Windows.Win32.Foundation.BOOL, MultiSampleType: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE, pQualityLevels: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CheckDepthStencilMatch(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, AdapterFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, RenderTargetFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, DepthStencilFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CheckDeviceFormatConversion(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, SourceFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, TargetFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetDeviceCaps(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, pCaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DCAPS9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetAdapterMonitor(self, Adapter: UInt32) -> win32more.Windows.Win32.Graphics.Gdi.HMONITOR: ...
    @commethod(16)
    def CreateDevice(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, hFocusWindow: win32more.Windows.Win32.Foundation.HWND, BehaviorFlags: UInt32, pPresentationParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENT_PARAMETERS), ppReturnedDeviceInterface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3D9Ex(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3D9
    _iid_ = Guid('{02177241-69fc-400c-8ff1-93a44df6861d}')
    @commethod(17)
    def GetAdapterModeCountEx(self, Adapter: UInt32, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEFILTER)) -> UInt32: ...
    @commethod(18)
    def EnumAdapterModesEx(self, Adapter: UInt32, pFilter: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEFILTER), Mode: UInt32, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEEX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetAdapterDisplayModeEx(self, Adapter: UInt32, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEEX), pRotation: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def CreateDeviceEx(self, Adapter: UInt32, DeviceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVTYPE, hFocusWindow: win32more.Windows.Win32.Foundation.HWND, BehaviorFlags: UInt32, pPresentationParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENT_PARAMETERS), pFullscreenDisplayMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEEX), ppReturnedDeviceInterface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9Ex)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def GetAdapterLUID(self, Adapter: UInt32, pLUID: POINTER(win32more.Windows.Win32.Foundation.LUID)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DBaseTexture9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DResource9
    _iid_ = Guid('{580ca87e-1d3c-4d54-991d-b7d3e3c298ce}')
    @commethod(11)
    def SetLOD(self, LODNew: UInt32) -> UInt32: ...
    @commethod(12)
    def GetLOD(self) -> UInt32: ...
    @commethod(13)
    def GetLevelCount(self) -> UInt32: ...
    @commethod(14)
    def SetAutoGenFilterType(self, FilterType: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetAutoGenFilterType(self) -> win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE: ...
    @commethod(16)
    def GenerateMipSubLevels(self) -> Void: ...
class IDirect3DCubeTexture9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9
    _iid_ = Guid('{fff32f81-d953-473a-9223-93d652aba93f}')
    @commethod(17)
    def GetLevelDesc(self, Level: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DSURFACE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetCubeMapSurface(self, FaceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES, Level: UInt32, ppCubeMapSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def LockRect(self, FaceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES, Level: UInt32, pLockedRect: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLOCKED_RECT), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def UnlockRect(self, FaceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def AddDirtyRect(self, FaceType: win32more.Windows.Win32.Graphics.Direct3D9.D3DCUBEMAP_FACES, pDirtyRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DDevice9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d0223b96-bf7a-43fd-92bd-a43b0d82b9eb}')
    @commethod(3)
    def TestCooperativeLevel(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetAvailableTextureMem(self) -> UInt32: ...
    @commethod(5)
    def EvictManagedResources(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDirect3D(self, ppD3D9: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3D9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDeviceCaps(self, pCaps: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DCAPS9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDisplayMode(self, iSwapChain: UInt32, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetCreationParameters(self, pParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVICE_CREATION_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCursorProperties(self, XHotSpot: UInt32, YHotSpot: UInt32, pCursorBitmap: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def SetCursorPosition(self, X: Int32, Y: Int32, Flags: UInt32) -> Void: ...
    @commethod(12)
    def ShowCursor(self, bShow: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(13)
    def CreateAdditionalSwapChain(self, pPresentationParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENT_PARAMETERS), pSwapChain: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSwapChain9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetSwapChain(self, iSwapChain: UInt32, pSwapChain: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSwapChain9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetNumberOfSwapChains(self) -> UInt32: ...
    @commethod(16)
    def Reset(self, pPresentationParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def Present(self, pSourceRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pDestRect: POINTER(win32more.Windows.Win32.Foundation.RECT), hDestWindowOverride: win32more.Windows.Win32.Foundation.HWND, pDirtyRegion: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetBackBuffer(self, iSwapChain: UInt32, iBackBuffer: UInt32, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DBACKBUFFER_TYPE, ppBackBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def GetRasterStatus(self, iSwapChain: UInt32, pRasterStatus: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DRASTER_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def SetDialogBoxMode(self, bEnableDialogs: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def SetGammaRamp(self, iSwapChain: UInt32, Flags: UInt32, pRamp: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DGAMMARAMP)) -> Void: ...
    @commethod(22)
    def GetGammaRamp(self, iSwapChain: UInt32, pRamp: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DGAMMARAMP)) -> Void: ...
    @commethod(23)
    def CreateTexture(self, Width: UInt32, Height: UInt32, Levels: UInt32, Usage: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppTexture: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DTexture9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def CreateVolumeTexture(self, Width: UInt32, Height: UInt32, Depth: UInt32, Levels: UInt32, Usage: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppVolumeTexture: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVolumeTexture9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def CreateCubeTexture(self, EdgeLength: UInt32, Levels: UInt32, Usage: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppCubeTexture: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DCubeTexture9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def CreateVertexBuffer(self, Length: UInt32, Usage: UInt32, FVF: UInt32, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppVertexBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexBuffer9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def CreateIndexBuffer(self, Length: UInt32, Usage: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppIndexBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DIndexBuffer9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def CreateRenderTarget(self, Width: UInt32, Height: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, MultiSample: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE, MultisampleQuality: UInt32, Lockable: win32more.Windows.Win32.Foundation.BOOL, ppSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def CreateDepthStencilSurface(self, Width: UInt32, Height: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, MultiSample: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE, MultisampleQuality: UInt32, Discard: win32more.Windows.Win32.Foundation.BOOL, ppSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def UpdateSurface(self, pSourceSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pSourceRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pDestinationSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pDestPoint: POINTER(win32more.Windows.Win32.Foundation.POINT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def UpdateTexture(self, pSourceTexture: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9, pDestinationTexture: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetRenderTargetData(self, pRenderTarget: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pDestSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def GetFrontBufferData(self, iSwapChain: UInt32, pDestSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def StretchRect(self, pSourceSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pSourceRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pDestSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pDestRect: POINTER(win32more.Windows.Win32.Foundation.RECT), Filter: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTUREFILTERTYPE) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def ColorFill(self, pSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), color: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def CreateOffscreenPlainSurface(self, Width: UInt32, Height: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def SetRenderTarget(self, RenderTargetIndex: UInt32, pRenderTarget: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def GetRenderTarget(self, RenderTargetIndex: UInt32, ppRenderTarget: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def SetDepthStencilSurface(self, pNewZStencil: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def GetDepthStencilSurface(self, ppZStencilSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def BeginScene(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def EndScene(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def Clear(self, Count: UInt32, pRects: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DRECT), Flags: UInt32, Color: UInt32, Z: Single, Stencil: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def SetTransform(self, State: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE, pMatrix: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3DMATRIX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def GetTransform(self, State: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE, pMatrix: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3DMATRIX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def MultiplyTransform(self, param0: win32more.Windows.Win32.Graphics.Direct3D9.D3DTRANSFORMSTATETYPE, param1: POINTER(win32more.Windows.Win32.Graphics.Direct3D.D3DMATRIX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def SetViewport(self, pViewport: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVIEWPORT9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def GetViewport(self, pViewport: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVIEWPORT9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def SetMaterial(self, pMaterial: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DMATERIAL9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def GetMaterial(self, pMaterial: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DMATERIAL9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def SetLight(self, Index: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHT9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(52)
    def GetLight(self, Index: UInt32, param1: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLIGHT9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def LightEnable(self, Index: UInt32, Enable: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def GetLightEnable(self, Index: UInt32, pEnable: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def SetClipPlane(self, Index: UInt32, pPlane: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def GetClipPlane(self, Index: UInt32, pPlane: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def SetRenderState(self, State: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE, Value: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def GetRenderState(self, State: win32more.Windows.Win32.Graphics.Direct3D9.D3DRENDERSTATETYPE, pValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def CreateStateBlock(self, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DSTATEBLOCKTYPE, ppSB: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DStateBlock9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(60)
    def BeginStateBlock(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def EndStateBlock(self, ppSB: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DStateBlock9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def SetClipStatus(self, pClipStatus: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DCLIPSTATUS9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def GetClipStatus(self, pClipStatus: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DCLIPSTATUS9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(64)
    def GetTexture(self, Stage: UInt32, ppTexture: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(65)
    def SetTexture(self, Stage: UInt32, pTexture: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def GetTextureStageState(self, Stage: UInt32, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE, pValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(67)
    def SetTextureStageState(self, Stage: UInt32, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DTEXTURESTAGESTATETYPE, Value: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def GetSamplerState(self, Sampler: UInt32, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE, pValue: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(69)
    def SetSamplerState(self, Sampler: UInt32, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DSAMPLERSTATETYPE, Value: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(70)
    def ValidateDevice(self, pNumPasses: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(71)
    def SetPaletteEntries(self, PaletteNumber: UInt32, pEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(72)
    def GetPaletteEntries(self, PaletteNumber: UInt32, pEntries: POINTER(win32more.Windows.Win32.Graphics.Gdi.PALETTEENTRY)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(73)
    def SetCurrentTexturePalette(self, PaletteNumber: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(74)
    def GetCurrentTexturePalette(self, PaletteNumber: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(75)
    def SetScissorRect(self, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(76)
    def GetScissorRect(self, pRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(77)
    def SetSoftwareVertexProcessing(self, bSoftware: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(78)
    def GetSoftwareVertexProcessing(self) -> win32more.Windows.Win32.Foundation.BOOL: ...
    @commethod(79)
    def SetNPatchMode(self, nSegments: Single) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(80)
    def GetNPatchMode(self) -> Single: ...
    @commethod(81)
    def DrawPrimitive(self, PrimitiveType: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE, StartVertex: UInt32, PrimitiveCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(82)
    def DrawIndexedPrimitive(self, param0: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE, BaseVertexIndex: Int32, MinVertexIndex: UInt32, NumVertices: UInt32, startIndex: UInt32, primCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(83)
    def DrawPrimitiveUP(self, PrimitiveType: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE, PrimitiveCount: UInt32, pVertexStreamZeroData: VoidPtr, VertexStreamZeroStride: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(84)
    def DrawIndexedPrimitiveUP(self, PrimitiveType: win32more.Windows.Win32.Graphics.Direct3D9.D3DPRIMITIVETYPE, MinVertexIndex: UInt32, NumVertices: UInt32, PrimitiveCount: UInt32, pIndexData: VoidPtr, IndexDataFormat: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, pVertexStreamZeroData: VoidPtr, VertexStreamZeroStride: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(85)
    def ProcessVertices(self, SrcStartIndex: UInt32, DestIndex: UInt32, VertexCount: UInt32, pDestBuffer: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexBuffer9, pVertexDecl: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexDeclaration9, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(86)
    def CreateVertexDeclaration(self, pVertexElements: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXELEMENT9), ppDecl: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexDeclaration9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(87)
    def SetVertexDeclaration(self, pDecl: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexDeclaration9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(88)
    def GetVertexDeclaration(self, ppDecl: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexDeclaration9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(89)
    def SetFVF(self, FVF: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(90)
    def GetFVF(self, pFVF: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(91)
    def CreateVertexShader(self, pFunction: POINTER(UInt32), ppShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexShader9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(92)
    def SetVertexShader(self, pShader: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexShader9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(93)
    def GetVertexShader(self, ppShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexShader9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(94)
    def SetVertexShaderConstantF(self, StartRegister: UInt32, pConstantData: POINTER(Single), Vector4fCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(95)
    def GetVertexShaderConstantF(self, StartRegister: UInt32, pConstantData: POINTER(Single), Vector4fCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(96)
    def SetVertexShaderConstantI(self, StartRegister: UInt32, pConstantData: POINTER(Int32), Vector4iCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(97)
    def GetVertexShaderConstantI(self, StartRegister: UInt32, pConstantData: POINTER(Int32), Vector4iCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(98)
    def SetVertexShaderConstantB(self, StartRegister: UInt32, pConstantData: POINTER(win32more.Windows.Win32.Foundation.BOOL), BoolCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(99)
    def GetVertexShaderConstantB(self, StartRegister: UInt32, pConstantData: POINTER(win32more.Windows.Win32.Foundation.BOOL), BoolCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(100)
    def SetStreamSource(self, StreamNumber: UInt32, pStreamData: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexBuffer9, OffsetInBytes: UInt32, Stride: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(101)
    def GetStreamSource(self, StreamNumber: UInt32, ppStreamData: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexBuffer9), pOffsetInBytes: POINTER(UInt32), pStride: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(102)
    def SetStreamSourceFreq(self, StreamNumber: UInt32, Setting: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(103)
    def GetStreamSourceFreq(self, StreamNumber: UInt32, pSetting: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(104)
    def SetIndices(self, pIndexData: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DIndexBuffer9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(105)
    def GetIndices(self, ppIndexData: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DIndexBuffer9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(106)
    def CreatePixelShader(self, pFunction: POINTER(UInt32), ppShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DPixelShader9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(107)
    def SetPixelShader(self, pShader: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DPixelShader9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(108)
    def GetPixelShader(self, ppShader: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DPixelShader9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(109)
    def SetPixelShaderConstantF(self, StartRegister: UInt32, pConstantData: POINTER(Single), Vector4fCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(110)
    def GetPixelShaderConstantF(self, StartRegister: UInt32, pConstantData: POINTER(Single), Vector4fCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(111)
    def SetPixelShaderConstantI(self, StartRegister: UInt32, pConstantData: POINTER(Int32), Vector4iCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(112)
    def GetPixelShaderConstantI(self, StartRegister: UInt32, pConstantData: POINTER(Int32), Vector4iCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(113)
    def SetPixelShaderConstantB(self, StartRegister: UInt32, pConstantData: POINTER(win32more.Windows.Win32.Foundation.BOOL), BoolCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(114)
    def GetPixelShaderConstantB(self, StartRegister: UInt32, pConstantData: POINTER(win32more.Windows.Win32.Foundation.BOOL), BoolCount: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(115)
    def DrawRectPatch(self, Handle: UInt32, pNumSegs: POINTER(Single), pRectPatchInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DRECTPATCH_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(116)
    def DrawTriPatch(self, Handle: UInt32, pNumSegs: POINTER(Single), pTriPatchInfo: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DTRIPATCH_INFO)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(117)
    def DeletePatch(self, Handle: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(118)
    def CreateQuery(self, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE, ppQuery: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DQuery9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DDevice9Ex(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9
    _iid_ = Guid('{b18b10ce-2649-405a-870f-95f777d4313a}')
    @commethod(119)
    def SetConvolutionMonoKernel(self, width: UInt32, height: UInt32, rows: POINTER(Single), columns: POINTER(Single)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(120)
    def ComposeRects(self, pSrc: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pDst: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9, pSrcRectDescs: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexBuffer9, NumRects: UInt32, pDstRectDescs: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVertexBuffer9, Operation: win32more.Windows.Win32.Graphics.Direct3D9.D3DCOMPOSERECTSOP, Xoffset: Int32, Yoffset: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(121)
    def PresentEx(self, pSourceRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pDestRect: POINTER(win32more.Windows.Win32.Foundation.RECT), hDestWindowOverride: win32more.Windows.Win32.Foundation.HWND, pDirtyRegion: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(122)
    def GetGPUThreadPriority(self, pPriority: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(123)
    def SetGPUThreadPriority(self, Priority: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(124)
    def WaitForVBlank(self, iSwapChain: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(125)
    def CheckResourceResidency(self, pResourceArray: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DResource9), NumResources: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(126)
    def SetMaximumFrameLatency(self, MaxLatency: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(127)
    def GetMaximumFrameLatency(self, pMaxLatency: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(128)
    def CheckDeviceState(self, hDestinationWindow: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(129)
    def CreateRenderTargetEx(self, Width: UInt32, Height: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, MultiSample: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE, MultisampleQuality: UInt32, Lockable: win32more.Windows.Win32.Foundation.BOOL, ppSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), Usage: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(130)
    def CreateOffscreenPlainSurfaceEx(self, Width: UInt32, Height: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, Pool: win32more.Windows.Win32.Graphics.Direct3D9.D3DPOOL, ppSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), Usage: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(131)
    def CreateDepthStencilSurfaceEx(self, Width: UInt32, Height: UInt32, Format: win32more.Windows.Win32.Graphics.Direct3D9.D3DFORMAT, MultiSample: win32more.Windows.Win32.Graphics.Direct3D9.D3DMULTISAMPLE_TYPE, MultisampleQuality: UInt32, Discard: win32more.Windows.Win32.Foundation.BOOL, ppSurface: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9), pSharedHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE), Usage: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(132)
    def ResetEx(self, pPresentationParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENT_PARAMETERS), pFullscreenDisplayMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEEX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(133)
    def GetDisplayModeEx(self, iSwapChain: UInt32, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEEX), pRotation: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DIndexBuffer9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DResource9
    _iid_ = Guid('{7c9dd65e-d3f7-4529-acee-785830acde35}')
    @commethod(11)
    def Lock(self, OffsetToLock: UInt32, SizeToLock: UInt32, ppbData: POINTER(VoidPtr), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Unlock(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DINDEXBUFFER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DPixelShader9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6d3bdbdc-5b02-4415-b852-ce5e8bccb289}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFunction(self, param0: VoidPtr, pSizeOfData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DQuery9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d9771460-a695-4f26-bbd3-27b840b541cc}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D9.D3DQUERYTYPE: ...
    @commethod(5)
    def GetDataSize(self) -> UInt32: ...
    @commethod(6)
    def Issue(self, dwIssueFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetData(self, pData: VoidPtr, dwSize: UInt32, dwGetDataFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DResource9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{05eec05d-8f7d-4362-b999-d1baf357c704}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetPrivateData(self, refguid: POINTER(Guid), pData: VoidPtr, SizeOfData: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPrivateData(self, refguid: POINTER(Guid), pData: VoidPtr, pSizeOfData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FreePrivateData(self, refguid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def SetPriority(self, PriorityNew: UInt32) -> UInt32: ...
    @commethod(8)
    def GetPriority(self) -> UInt32: ...
    @commethod(9)
    def PreLoad(self) -> Void: ...
    @commethod(10)
    def GetType(self) -> win32more.Windows.Win32.Graphics.Direct3D9.D3DRESOURCETYPE: ...
class IDirect3DStateBlock9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{b07c4fe5-310d-4ba8-a23c-4f0f206f218b}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Capture(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Apply(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DSurface9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DResource9
    _iid_ = Guid('{0cfbaf3a-9ff6-429a-99b3-a2796af8b89b}')
    @commethod(11)
    def GetContainer(self, riid: POINTER(Guid), ppContainer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DSURFACE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def LockRect(self, pLockedRect: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLOCKED_RECT), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def UnlockRect(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetDC(self, phdc: POINTER(win32more.Windows.Win32.Graphics.Gdi.HDC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def ReleaseDC(self, hdc: win32more.Windows.Win32.Graphics.Gdi.HDC) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DSwapChain9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{794950f2-adfc-458a-905e-10a10b0b503b}')
    @commethod(3)
    def Present(self, pSourceRect: POINTER(win32more.Windows.Win32.Foundation.RECT), pDestRect: POINTER(win32more.Windows.Win32.Foundation.RECT), hDestWindowOverride: win32more.Windows.Win32.Foundation.HWND, pDirtyRegion: POINTER(win32more.Windows.Win32.Graphics.Gdi.RGNDATA), dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFrontBufferData(self, pDestSurface: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetBackBuffer(self, iBackBuffer: UInt32, Type: win32more.Windows.Win32.Graphics.Direct3D9.D3DBACKBUFFER_TYPE, ppBackBuffer: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetRasterStatus(self, pRasterStatus: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DRASTER_STATUS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDisplayMode(self, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetPresentParameters(self, pPresentationParameters: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENT_PARAMETERS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DSwapChain9Ex(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSwapChain9
    _iid_ = Guid('{91886caf-1c3d-4d2e-a0ab-3e4c7d8d3303}')
    @commethod(10)
    def GetLastPresentCount(self, pLastPresentCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetPresentStats(self, pPresentationStatistics: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DPRESENTSTATS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetDisplayModeEx(self, pMode: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYMODEEX), pRotation: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDISPLAYROTATION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DTexture9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9
    _iid_ = Guid('{85c31227-3de5-4f00-9b3a-f11ac38c18b5}')
    @commethod(17)
    def GetLevelDesc(self, Level: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DSURFACE_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSurfaceLevel(self, Level: UInt32, ppSurfaceLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DSurface9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def LockRect(self, Level: UInt32, pLockedRect: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLOCKED_RECT), pRect: POINTER(win32more.Windows.Win32.Foundation.RECT), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def UnlockRect(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def AddDirtyRect(self, pDirtyRect: POINTER(win32more.Windows.Win32.Foundation.RECT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DVertexBuffer9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DResource9
    _iid_ = Guid('{b64bb1b5-fd70-4df6-bf91-19d0a12455e3}')
    @commethod(11)
    def Lock(self, OffsetToLock: UInt32, SizeToLock: UInt32, ppbData: POINTER(VoidPtr), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Unlock(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXBUFFER_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DVertexDeclaration9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{dd13c59c-36fa-4098-a8fb-c7ed39dc8546}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDeclaration(self, pElement: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVERTEXELEMENT9), pNumElements: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DVertexShader9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{efc5557e-6265-4613-8a94-43857889eb36}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetFunction(self, param0: VoidPtr, pSizeOfData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DVolume9(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{24f416e6-1f67-4aa7-b88e-d33f6f3128a1}')
    @commethod(3)
    def GetDevice(self, ppDevice: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DDevice9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetPrivateData(self, refguid: POINTER(Guid), pData: VoidPtr, SizeOfData: UInt32, Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetPrivateData(self, refguid: POINTER(Guid), pData: VoidPtr, pSizeOfData: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def FreePrivateData(self, refguid: POINTER(Guid)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetContainer(self, riid: POINTER(Guid), ppContainer: POINTER(VoidPtr)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDesc(self, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVOLUME_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def LockBox(self, pLockedVolume: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLOCKED_BOX), pBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DBOX), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def UnlockBox(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDirect3DVolumeTexture9(ComPtr):
    extends: win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DBaseTexture9
    _iid_ = Guid('{2518526c-e789-4111-a7b9-47ef328d13e6}')
    @commethod(17)
    def GetLevelDesc(self, Level: UInt32, pDesc: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DVOLUME_DESC)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetVolumeLevel(self, Level: UInt32, ppVolumeLevel: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.IDirect3DVolume9)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def LockBox(self, Level: UInt32, pLockedVolume: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DLOCKED_BOX), pBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DBOX), Flags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def UnlockBox(self, Level: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def AddDirtyBox(self, pDirtyBox: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DBOX)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPD3DENUMDEVICESCALLBACK(lpGuid: POINTER(Guid), lpDeviceDescription: win32more.Windows.Win32.Foundation.PSTR, lpDeviceName: win32more.Windows.Win32.Foundation.PSTR, param3: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVICEDESC), param4: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVICEDESC), param5: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPD3DENUMDEVICESCALLBACK7(lpDeviceDescription: win32more.Windows.Win32.Foundation.PSTR, lpDeviceName: win32more.Windows.Win32.Foundation.PSTR, param2: POINTER(win32more.Windows.Win32.Graphics.Direct3D9.D3DDEVICEDESC7), param3: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPD3DENUMPIXELFORMATSCALLBACK(lpDDPixFmt: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDPIXELFORMAT), lpContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPD3DENUMTEXTUREFORMATSCALLBACK(lpDdsd: POINTER(win32more.Windows.Win32.Graphics.DirectDraw.DDSURFACEDESC), lpContext: VoidPtr) -> win32more.Windows.Win32.Foundation.HRESULT: ...
@winfunctype_pointer
def LPD3DVALIDATECALLBACK(lpUserArg: VoidPtr, dwOffset: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...


make_ready(__name__)
